# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['ProjectCardArgs', 'ProjectCard']

@pulumi.input_type
class ProjectCardArgs:
    def __init__(__self__, *,
                 column_id: pulumi.Input[str],
                 content_id: Optional[pulumi.Input[int]] = None,
                 content_type: Optional[pulumi.Input[str]] = None,
                 note: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a ProjectCard resource.
        :param pulumi.Input[str] column_id: The ID of the card.
        :param pulumi.Input[int] content_id: `github_issue.issue_id`.
        :param pulumi.Input[str] content_type: Must be either `Issue` or `PullRequest`
               
               **Remarks:** You must either set the `note` attribute or both `content_id` and `content_type`.
               See note example or issue example for more information.
        :param pulumi.Input[str] note: The note contents of the card. Markdown supported.
        """
        pulumi.set(__self__, "column_id", column_id)
        if content_id is not None:
            pulumi.set(__self__, "content_id", content_id)
        if content_type is not None:
            pulumi.set(__self__, "content_type", content_type)
        if note is not None:
            pulumi.set(__self__, "note", note)

    @property
    @pulumi.getter(name="columnId")
    def column_id(self) -> pulumi.Input[str]:
        """
        The ID of the card.
        """
        return pulumi.get(self, "column_id")

    @column_id.setter
    def column_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "column_id", value)

    @property
    @pulumi.getter(name="contentId")
    def content_id(self) -> Optional[pulumi.Input[int]]:
        """
        `github_issue.issue_id`.
        """
        return pulumi.get(self, "content_id")

    @content_id.setter
    def content_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "content_id", value)

    @property
    @pulumi.getter(name="contentType")
    def content_type(self) -> Optional[pulumi.Input[str]]:
        """
        Must be either `Issue` or `PullRequest`

        **Remarks:** You must either set the `note` attribute or both `content_id` and `content_type`.
        See note example or issue example for more information.
        """
        return pulumi.get(self, "content_type")

    @content_type.setter
    def content_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "content_type", value)

    @property
    @pulumi.getter
    def note(self) -> Optional[pulumi.Input[str]]:
        """
        The note contents of the card. Markdown supported.
        """
        return pulumi.get(self, "note")

    @note.setter
    def note(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "note", value)


@pulumi.input_type
class _ProjectCardState:
    def __init__(__self__, *,
                 card_id: Optional[pulumi.Input[int]] = None,
                 column_id: Optional[pulumi.Input[str]] = None,
                 content_id: Optional[pulumi.Input[int]] = None,
                 content_type: Optional[pulumi.Input[str]] = None,
                 etag: Optional[pulumi.Input[str]] = None,
                 note: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering ProjectCard resources.
        :param pulumi.Input[int] card_id: The ID of the card.
        :param pulumi.Input[str] column_id: The ID of the card.
        :param pulumi.Input[int] content_id: `github_issue.issue_id`.
        :param pulumi.Input[str] content_type: Must be either `Issue` or `PullRequest`
               
               **Remarks:** You must either set the `note` attribute or both `content_id` and `content_type`.
               See note example or issue example for more information.
        :param pulumi.Input[str] note: The note contents of the card. Markdown supported.
        """
        if card_id is not None:
            pulumi.set(__self__, "card_id", card_id)
        if column_id is not None:
            pulumi.set(__self__, "column_id", column_id)
        if content_id is not None:
            pulumi.set(__self__, "content_id", content_id)
        if content_type is not None:
            pulumi.set(__self__, "content_type", content_type)
        if etag is not None:
            pulumi.set(__self__, "etag", etag)
        if note is not None:
            pulumi.set(__self__, "note", note)

    @property
    @pulumi.getter(name="cardId")
    def card_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the card.
        """
        return pulumi.get(self, "card_id")

    @card_id.setter
    def card_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "card_id", value)

    @property
    @pulumi.getter(name="columnId")
    def column_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the card.
        """
        return pulumi.get(self, "column_id")

    @column_id.setter
    def column_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "column_id", value)

    @property
    @pulumi.getter(name="contentId")
    def content_id(self) -> Optional[pulumi.Input[int]]:
        """
        `github_issue.issue_id`.
        """
        return pulumi.get(self, "content_id")

    @content_id.setter
    def content_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "content_id", value)

    @property
    @pulumi.getter(name="contentType")
    def content_type(self) -> Optional[pulumi.Input[str]]:
        """
        Must be either `Issue` or `PullRequest`

        **Remarks:** You must either set the `note` attribute or both `content_id` and `content_type`.
        See note example or issue example for more information.
        """
        return pulumi.get(self, "content_type")

    @content_type.setter
    def content_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "content_type", value)

    @property
    @pulumi.getter
    def etag(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "etag")

    @etag.setter
    def etag(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "etag", value)

    @property
    @pulumi.getter
    def note(self) -> Optional[pulumi.Input[str]]:
        """
        The note contents of the card. Markdown supported.
        """
        return pulumi.get(self, "note")

    @note.setter
    def note(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "note", value)


class ProjectCard(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 column_id: Optional[pulumi.Input[str]] = None,
                 content_id: Optional[pulumi.Input[int]] = None,
                 content_type: Optional[pulumi.Input[str]] = None,
                 note: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource allows you to create and manage cards for GitHub projects.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        project = github.OrganizationProject("project",
            name="An Organization Project",
            body="This is an organization project.")
        column = github.ProjectColumn("column",
            project_id=project.id,
            name="Backlog")
        card = github.ProjectCard("card",
            column_id=column.column_id,
            note="## Unaccepted 👇")
        ```

        ### Adding An Issue To A Project

        ```python
        import pulumi
        import pulumi_github as github

        test = github.Repository("test",
            name="myrepo",
            has_projects=True,
            has_issues=True)
        test_issue = github.Issue("test",
            repository=test.id,
            title="Test issue title",
            body="Test issue body")
        test_repository_project = github.RepositoryProject("test",
            name="test",
            repository=test.name,
            body="this is a test project")
        test_project_column = github.ProjectColumn("test",
            project_id=test_repository_project.id,
            name="Backlog")
        test_project_card = github.ProjectCard("test",
            column_id=test_project_column.column_id,
            content_id=test_issue.issue_id,
            content_type="Issue")
        ```

        ## Import

        A GitHub Project Card can be imported using its [Card ID](https://developer.github.com/v3/projects/cards/#get-a-project-card):

        ```sh
        $ pulumi import github:index/projectCard:ProjectCard card 01234567
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] column_id: The ID of the card.
        :param pulumi.Input[int] content_id: `github_issue.issue_id`.
        :param pulumi.Input[str] content_type: Must be either `Issue` or `PullRequest`
               
               **Remarks:** You must either set the `note` attribute or both `content_id` and `content_type`.
               See note example or issue example for more information.
        :param pulumi.Input[str] note: The note contents of the card. Markdown supported.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectCardArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource allows you to create and manage cards for GitHub projects.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        project = github.OrganizationProject("project",
            name="An Organization Project",
            body="This is an organization project.")
        column = github.ProjectColumn("column",
            project_id=project.id,
            name="Backlog")
        card = github.ProjectCard("card",
            column_id=column.column_id,
            note="## Unaccepted 👇")
        ```

        ### Adding An Issue To A Project

        ```python
        import pulumi
        import pulumi_github as github

        test = github.Repository("test",
            name="myrepo",
            has_projects=True,
            has_issues=True)
        test_issue = github.Issue("test",
            repository=test.id,
            title="Test issue title",
            body="Test issue body")
        test_repository_project = github.RepositoryProject("test",
            name="test",
            repository=test.name,
            body="this is a test project")
        test_project_column = github.ProjectColumn("test",
            project_id=test_repository_project.id,
            name="Backlog")
        test_project_card = github.ProjectCard("test",
            column_id=test_project_column.column_id,
            content_id=test_issue.issue_id,
            content_type="Issue")
        ```

        ## Import

        A GitHub Project Card can be imported using its [Card ID](https://developer.github.com/v3/projects/cards/#get-a-project-card):

        ```sh
        $ pulumi import github:index/projectCard:ProjectCard card 01234567
        ```

        :param str resource_name: The name of the resource.
        :param ProjectCardArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectCardArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 column_id: Optional[pulumi.Input[str]] = None,
                 content_id: Optional[pulumi.Input[int]] = None,
                 content_type: Optional[pulumi.Input[str]] = None,
                 note: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectCardArgs.__new__(ProjectCardArgs)

            if column_id is None and not opts.urn:
                raise TypeError("Missing required property 'column_id'")
            __props__.__dict__["column_id"] = column_id
            __props__.__dict__["content_id"] = content_id
            __props__.__dict__["content_type"] = content_type
            __props__.__dict__["note"] = note
            __props__.__dict__["card_id"] = None
            __props__.__dict__["etag"] = None
        super(ProjectCard, __self__).__init__(
            'github:index/projectCard:ProjectCard',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            card_id: Optional[pulumi.Input[int]] = None,
            column_id: Optional[pulumi.Input[str]] = None,
            content_id: Optional[pulumi.Input[int]] = None,
            content_type: Optional[pulumi.Input[str]] = None,
            etag: Optional[pulumi.Input[str]] = None,
            note: Optional[pulumi.Input[str]] = None) -> 'ProjectCard':
        """
        Get an existing ProjectCard resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] card_id: The ID of the card.
        :param pulumi.Input[str] column_id: The ID of the card.
        :param pulumi.Input[int] content_id: `github_issue.issue_id`.
        :param pulumi.Input[str] content_type: Must be either `Issue` or `PullRequest`
               
               **Remarks:** You must either set the `note` attribute or both `content_id` and `content_type`.
               See note example or issue example for more information.
        :param pulumi.Input[str] note: The note contents of the card. Markdown supported.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectCardState.__new__(_ProjectCardState)

        __props__.__dict__["card_id"] = card_id
        __props__.__dict__["column_id"] = column_id
        __props__.__dict__["content_id"] = content_id
        __props__.__dict__["content_type"] = content_type
        __props__.__dict__["etag"] = etag
        __props__.__dict__["note"] = note
        return ProjectCard(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="cardId")
    def card_id(self) -> pulumi.Output[int]:
        """
        The ID of the card.
        """
        return pulumi.get(self, "card_id")

    @property
    @pulumi.getter(name="columnId")
    def column_id(self) -> pulumi.Output[str]:
        """
        The ID of the card.
        """
        return pulumi.get(self, "column_id")

    @property
    @pulumi.getter(name="contentId")
    def content_id(self) -> pulumi.Output[Optional[int]]:
        """
        `github_issue.issue_id`.
        """
        return pulumi.get(self, "content_id")

    @property
    @pulumi.getter(name="contentType")
    def content_type(self) -> pulumi.Output[Optional[str]]:
        """
        Must be either `Issue` or `PullRequest`

        **Remarks:** You must either set the `note` attribute or both `content_id` and `content_type`.
        See note example or issue example for more information.
        """
        return pulumi.get(self, "content_type")

    @property
    @pulumi.getter
    def etag(self) -> pulumi.Output[str]:
        return pulumi.get(self, "etag")

    @property
    @pulumi.getter
    def note(self) -> pulumi.Output[Optional[str]]:
        """
        The note contents of the card. Markdown supported.
        """
        return pulumi.get(self, "note")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetOrganizationResult',
    'AwaitableGetOrganizationResult',
    'get_organization',
    'get_organization_output',
]

@pulumi.output_type
class GetOrganizationResult:
    """
    A collection of values returned by getOrganization.
    """
    def __init__(__self__, advanced_security_enabled_for_new_repositories=None, default_repository_permission=None, dependabot_alerts_enabled_for_new_repositories=None, dependabot_security_updates_enabled_for_new_repositories=None, dependency_graph_enabled_for_new_repositories=None, description=None, id=None, ignore_archived_repos=None, login=None, members=None, members_allowed_repository_creation_type=None, members_can_create_internal_repositories=None, members_can_create_pages=None, members_can_create_private_pages=None, members_can_create_private_repositories=None, members_can_create_public_pages=None, members_can_create_public_repositories=None, members_can_create_repositories=None, members_can_fork_private_repositories=None, name=None, node_id=None, orgname=None, plan=None, repositories=None, secret_scanning_enabled_for_new_repositories=None, secret_scanning_push_protection_enabled_for_new_repositories=None, two_factor_requirement_enabled=None, users=None, web_commit_signoff_required=None):
        if advanced_security_enabled_for_new_repositories and not isinstance(advanced_security_enabled_for_new_repositories, bool):
            raise TypeError("Expected argument 'advanced_security_enabled_for_new_repositories' to be a bool")
        pulumi.set(__self__, "advanced_security_enabled_for_new_repositories", advanced_security_enabled_for_new_repositories)
        if default_repository_permission and not isinstance(default_repository_permission, str):
            raise TypeError("Expected argument 'default_repository_permission' to be a str")
        pulumi.set(__self__, "default_repository_permission", default_repository_permission)
        if dependabot_alerts_enabled_for_new_repositories and not isinstance(dependabot_alerts_enabled_for_new_repositories, bool):
            raise TypeError("Expected argument 'dependabot_alerts_enabled_for_new_repositories' to be a bool")
        pulumi.set(__self__, "dependabot_alerts_enabled_for_new_repositories", dependabot_alerts_enabled_for_new_repositories)
        if dependabot_security_updates_enabled_for_new_repositories and not isinstance(dependabot_security_updates_enabled_for_new_repositories, bool):
            raise TypeError("Expected argument 'dependabot_security_updates_enabled_for_new_repositories' to be a bool")
        pulumi.set(__self__, "dependabot_security_updates_enabled_for_new_repositories", dependabot_security_updates_enabled_for_new_repositories)
        if dependency_graph_enabled_for_new_repositories and not isinstance(dependency_graph_enabled_for_new_repositories, bool):
            raise TypeError("Expected argument 'dependency_graph_enabled_for_new_repositories' to be a bool")
        pulumi.set(__self__, "dependency_graph_enabled_for_new_repositories", dependency_graph_enabled_for_new_repositories)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ignore_archived_repos and not isinstance(ignore_archived_repos, bool):
            raise TypeError("Expected argument 'ignore_archived_repos' to be a bool")
        pulumi.set(__self__, "ignore_archived_repos", ignore_archived_repos)
        if login and not isinstance(login, str):
            raise TypeError("Expected argument 'login' to be a str")
        pulumi.set(__self__, "login", login)
        if members and not isinstance(members, list):
            raise TypeError("Expected argument 'members' to be a list")
        pulumi.set(__self__, "members", members)
        if members_allowed_repository_creation_type and not isinstance(members_allowed_repository_creation_type, str):
            raise TypeError("Expected argument 'members_allowed_repository_creation_type' to be a str")
        pulumi.set(__self__, "members_allowed_repository_creation_type", members_allowed_repository_creation_type)
        if members_can_create_internal_repositories and not isinstance(members_can_create_internal_repositories, bool):
            raise TypeError("Expected argument 'members_can_create_internal_repositories' to be a bool")
        pulumi.set(__self__, "members_can_create_internal_repositories", members_can_create_internal_repositories)
        if members_can_create_pages and not isinstance(members_can_create_pages, bool):
            raise TypeError("Expected argument 'members_can_create_pages' to be a bool")
        pulumi.set(__self__, "members_can_create_pages", members_can_create_pages)
        if members_can_create_private_pages and not isinstance(members_can_create_private_pages, bool):
            raise TypeError("Expected argument 'members_can_create_private_pages' to be a bool")
        pulumi.set(__self__, "members_can_create_private_pages", members_can_create_private_pages)
        if members_can_create_private_repositories and not isinstance(members_can_create_private_repositories, bool):
            raise TypeError("Expected argument 'members_can_create_private_repositories' to be a bool")
        pulumi.set(__self__, "members_can_create_private_repositories", members_can_create_private_repositories)
        if members_can_create_public_pages and not isinstance(members_can_create_public_pages, bool):
            raise TypeError("Expected argument 'members_can_create_public_pages' to be a bool")
        pulumi.set(__self__, "members_can_create_public_pages", members_can_create_public_pages)
        if members_can_create_public_repositories and not isinstance(members_can_create_public_repositories, bool):
            raise TypeError("Expected argument 'members_can_create_public_repositories' to be a bool")
        pulumi.set(__self__, "members_can_create_public_repositories", members_can_create_public_repositories)
        if members_can_create_repositories and not isinstance(members_can_create_repositories, bool):
            raise TypeError("Expected argument 'members_can_create_repositories' to be a bool")
        pulumi.set(__self__, "members_can_create_repositories", members_can_create_repositories)
        if members_can_fork_private_repositories and not isinstance(members_can_fork_private_repositories, bool):
            raise TypeError("Expected argument 'members_can_fork_private_repositories' to be a bool")
        pulumi.set(__self__, "members_can_fork_private_repositories", members_can_fork_private_repositories)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if node_id and not isinstance(node_id, str):
            raise TypeError("Expected argument 'node_id' to be a str")
        pulumi.set(__self__, "node_id", node_id)
        if orgname and not isinstance(orgname, str):
            raise TypeError("Expected argument 'orgname' to be a str")
        pulumi.set(__self__, "orgname", orgname)
        if plan and not isinstance(plan, str):
            raise TypeError("Expected argument 'plan' to be a str")
        pulumi.set(__self__, "plan", plan)
        if repositories and not isinstance(repositories, list):
            raise TypeError("Expected argument 'repositories' to be a list")
        pulumi.set(__self__, "repositories", repositories)
        if secret_scanning_enabled_for_new_repositories and not isinstance(secret_scanning_enabled_for_new_repositories, bool):
            raise TypeError("Expected argument 'secret_scanning_enabled_for_new_repositories' to be a bool")
        pulumi.set(__self__, "secret_scanning_enabled_for_new_repositories", secret_scanning_enabled_for_new_repositories)
        if secret_scanning_push_protection_enabled_for_new_repositories and not isinstance(secret_scanning_push_protection_enabled_for_new_repositories, bool):
            raise TypeError("Expected argument 'secret_scanning_push_protection_enabled_for_new_repositories' to be a bool")
        pulumi.set(__self__, "secret_scanning_push_protection_enabled_for_new_repositories", secret_scanning_push_protection_enabled_for_new_repositories)
        if two_factor_requirement_enabled and not isinstance(two_factor_requirement_enabled, bool):
            raise TypeError("Expected argument 'two_factor_requirement_enabled' to be a bool")
        pulumi.set(__self__, "two_factor_requirement_enabled", two_factor_requirement_enabled)
        if users and not isinstance(users, list):
            raise TypeError("Expected argument 'users' to be a list")
        pulumi.set(__self__, "users", users)
        if web_commit_signoff_required and not isinstance(web_commit_signoff_required, bool):
            raise TypeError("Expected argument 'web_commit_signoff_required' to be a bool")
        pulumi.set(__self__, "web_commit_signoff_required", web_commit_signoff_required)

    @property
    @pulumi.getter(name="advancedSecurityEnabledForNewRepositories")
    def advanced_security_enabled_for_new_repositories(self) -> bool:
        """
        Whether advanced security is enabled for new repositories.
        """
        return pulumi.get(self, "advanced_security_enabled_for_new_repositories")

    @property
    @pulumi.getter(name="defaultRepositoryPermission")
    def default_repository_permission(self) -> str:
        """
        Default permission level members have for organization repositories.
        """
        return pulumi.get(self, "default_repository_permission")

    @property
    @pulumi.getter(name="dependabotAlertsEnabledForNewRepositories")
    def dependabot_alerts_enabled_for_new_repositories(self) -> bool:
        """
        Whether Dependabot alerts is automatically enabled for new repositories.
        """
        return pulumi.get(self, "dependabot_alerts_enabled_for_new_repositories")

    @property
    @pulumi.getter(name="dependabotSecurityUpdatesEnabledForNewRepositories")
    def dependabot_security_updates_enabled_for_new_repositories(self) -> bool:
        """
        Whether Dependabot security updates is automatically enabled for new repositories.
        """
        return pulumi.get(self, "dependabot_security_updates_enabled_for_new_repositories")

    @property
    @pulumi.getter(name="dependencyGraphEnabledForNewRepositories")
    def dependency_graph_enabled_for_new_repositories(self) -> bool:
        """
        Whether dependency graph is automatically enabled for new repositories.
        """
        return pulumi.get(self, "dependency_graph_enabled_for_new_repositories")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        The organization account description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="ignoreArchivedRepos")
    def ignore_archived_repos(self) -> Optional[bool]:
        return pulumi.get(self, "ignore_archived_repos")

    @property
    @pulumi.getter
    def login(self) -> str:
        """
        The members login
        """
        return pulumi.get(self, "login")

    @property
    @pulumi.getter
    @_utilities.deprecated("""Use `users` instead by replacing `github_organization.example.members` to `github_organization.example.users[*].login`. Expect this field to be removed in next major version.""")
    def members(self) -> Sequence[str]:
        """
        **Deprecated**: use `users` instead by replacing `github_organization.example.members` to `github_organization.example.users[*].login` which will give you the same value, expect this field to be removed in next major version
        """
        return pulumi.get(self, "members")

    @property
    @pulumi.getter(name="membersAllowedRepositoryCreationType")
    def members_allowed_repository_creation_type(self) -> str:
        """
        The type of repository allowed to be created by members of the organization. Can be one of `ALL`, `PUBLIC`, `PRIVATE`, `NONE`.
        """
        return pulumi.get(self, "members_allowed_repository_creation_type")

    @property
    @pulumi.getter(name="membersCanCreateInternalRepositories")
    def members_can_create_internal_repositories(self) -> bool:
        """
        Whether organization members can create internal repositories.
        """
        return pulumi.get(self, "members_can_create_internal_repositories")

    @property
    @pulumi.getter(name="membersCanCreatePages")
    def members_can_create_pages(self) -> bool:
        """
        Whether organization members can create pages sites.
        """
        return pulumi.get(self, "members_can_create_pages")

    @property
    @pulumi.getter(name="membersCanCreatePrivatePages")
    def members_can_create_private_pages(self) -> bool:
        """
        Whether organization members can create private pages sites.
        """
        return pulumi.get(self, "members_can_create_private_pages")

    @property
    @pulumi.getter(name="membersCanCreatePrivateRepositories")
    def members_can_create_private_repositories(self) -> bool:
        """
        Whether organization members can create private repositories.
        """
        return pulumi.get(self, "members_can_create_private_repositories")

    @property
    @pulumi.getter(name="membersCanCreatePublicPages")
    def members_can_create_public_pages(self) -> bool:
        """
        Whether organization members can create public pages sites.
        """
        return pulumi.get(self, "members_can_create_public_pages")

    @property
    @pulumi.getter(name="membersCanCreatePublicRepositories")
    def members_can_create_public_repositories(self) -> bool:
        """
        Whether organization members can create public repositories.
        """
        return pulumi.get(self, "members_can_create_public_repositories")

    @property
    @pulumi.getter(name="membersCanCreateRepositories")
    def members_can_create_repositories(self) -> bool:
        """
        Whether non-admin organization members can create repositories.
        """
        return pulumi.get(self, "members_can_create_repositories")

    @property
    @pulumi.getter(name="membersCanForkPrivateRepositories")
    def members_can_fork_private_repositories(self) -> bool:
        """
        Whether organization members can create private repository forks.
        """
        return pulumi.get(self, "members_can_fork_private_repositories")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The organization's public profile name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nodeId")
    def node_id(self) -> str:
        """
        GraphQL global node ID for use with the v4 API
        """
        return pulumi.get(self, "node_id")

    @property
    @pulumi.getter
    def orgname(self) -> str:
        """
        The organization's name as used in URLs and the API
        """
        return pulumi.get(self, "orgname")

    @property
    @pulumi.getter
    def plan(self) -> str:
        """
        The organization account plan name
        """
        return pulumi.get(self, "plan")

    @property
    @pulumi.getter
    def repositories(self) -> Sequence[str]:
        """
        (`list`) A list of the full names of the repositories in the organization formatted as `owner/name` strings
        """
        return pulumi.get(self, "repositories")

    @property
    @pulumi.getter(name="secretScanningEnabledForNewRepositories")
    def secret_scanning_enabled_for_new_repositories(self) -> bool:
        """
        Whether secret scanning is automatically enabled for new repositories.
        """
        return pulumi.get(self, "secret_scanning_enabled_for_new_repositories")

    @property
    @pulumi.getter(name="secretScanningPushProtectionEnabledForNewRepositories")
    def secret_scanning_push_protection_enabled_for_new_repositories(self) -> bool:
        """
        Whether secret scanning push protection is automatically enabled for new repositories.
        """
        return pulumi.get(self, "secret_scanning_push_protection_enabled_for_new_repositories")

    @property
    @pulumi.getter(name="twoFactorRequirementEnabled")
    def two_factor_requirement_enabled(self) -> bool:
        """
        Whether two-factor authentication is required for all members of the organization.
        """
        return pulumi.get(self, "two_factor_requirement_enabled")

    @property
    @pulumi.getter
    def users(self) -> Sequence[Mapping[str, str]]:
        """
        (`list`) A list with the members of the organization with following fields:
        """
        return pulumi.get(self, "users")

    @property
    @pulumi.getter(name="webCommitSignoffRequired")
    def web_commit_signoff_required(self) -> bool:
        """
        Whether organization members must sign all commits.
        """
        return pulumi.get(self, "web_commit_signoff_required")


class AwaitableGetOrganizationResult(GetOrganizationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOrganizationResult(
            advanced_security_enabled_for_new_repositories=self.advanced_security_enabled_for_new_repositories,
            default_repository_permission=self.default_repository_permission,
            dependabot_alerts_enabled_for_new_repositories=self.dependabot_alerts_enabled_for_new_repositories,
            dependabot_security_updates_enabled_for_new_repositories=self.dependabot_security_updates_enabled_for_new_repositories,
            dependency_graph_enabled_for_new_repositories=self.dependency_graph_enabled_for_new_repositories,
            description=self.description,
            id=self.id,
            ignore_archived_repos=self.ignore_archived_repos,
            login=self.login,
            members=self.members,
            members_allowed_repository_creation_type=self.members_allowed_repository_creation_type,
            members_can_create_internal_repositories=self.members_can_create_internal_repositories,
            members_can_create_pages=self.members_can_create_pages,
            members_can_create_private_pages=self.members_can_create_private_pages,
            members_can_create_private_repositories=self.members_can_create_private_repositories,
            members_can_create_public_pages=self.members_can_create_public_pages,
            members_can_create_public_repositories=self.members_can_create_public_repositories,
            members_can_create_repositories=self.members_can_create_repositories,
            members_can_fork_private_repositories=self.members_can_fork_private_repositories,
            name=self.name,
            node_id=self.node_id,
            orgname=self.orgname,
            plan=self.plan,
            repositories=self.repositories,
            secret_scanning_enabled_for_new_repositories=self.secret_scanning_enabled_for_new_repositories,
            secret_scanning_push_protection_enabled_for_new_repositories=self.secret_scanning_push_protection_enabled_for_new_repositories,
            two_factor_requirement_enabled=self.two_factor_requirement_enabled,
            users=self.users,
            web_commit_signoff_required=self.web_commit_signoff_required)


def get_organization(ignore_archived_repos: Optional[bool] = None,
                     name: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOrganizationResult:
    """
    Use this data source to retrieve basic information about a GitHub Organization.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_github as github

    example = github.get_organization(name="github")
    ```


    :param bool ignore_archived_repos: Whether or not to include archived repos in the `repositories` list
    :param str name: The organization's public profile name
    """
    __args__ = dict()
    __args__['ignoreArchivedRepos'] = ignore_archived_repos
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('github:index/getOrganization:getOrganization', __args__, opts=opts, typ=GetOrganizationResult).value

    return AwaitableGetOrganizationResult(
        advanced_security_enabled_for_new_repositories=pulumi.get(__ret__, 'advanced_security_enabled_for_new_repositories'),
        default_repository_permission=pulumi.get(__ret__, 'default_repository_permission'),
        dependabot_alerts_enabled_for_new_repositories=pulumi.get(__ret__, 'dependabot_alerts_enabled_for_new_repositories'),
        dependabot_security_updates_enabled_for_new_repositories=pulumi.get(__ret__, 'dependabot_security_updates_enabled_for_new_repositories'),
        dependency_graph_enabled_for_new_repositories=pulumi.get(__ret__, 'dependency_graph_enabled_for_new_repositories'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        ignore_archived_repos=pulumi.get(__ret__, 'ignore_archived_repos'),
        login=pulumi.get(__ret__, 'login'),
        members=pulumi.get(__ret__, 'members'),
        members_allowed_repository_creation_type=pulumi.get(__ret__, 'members_allowed_repository_creation_type'),
        members_can_create_internal_repositories=pulumi.get(__ret__, 'members_can_create_internal_repositories'),
        members_can_create_pages=pulumi.get(__ret__, 'members_can_create_pages'),
        members_can_create_private_pages=pulumi.get(__ret__, 'members_can_create_private_pages'),
        members_can_create_private_repositories=pulumi.get(__ret__, 'members_can_create_private_repositories'),
        members_can_create_public_pages=pulumi.get(__ret__, 'members_can_create_public_pages'),
        members_can_create_public_repositories=pulumi.get(__ret__, 'members_can_create_public_repositories'),
        members_can_create_repositories=pulumi.get(__ret__, 'members_can_create_repositories'),
        members_can_fork_private_repositories=pulumi.get(__ret__, 'members_can_fork_private_repositories'),
        name=pulumi.get(__ret__, 'name'),
        node_id=pulumi.get(__ret__, 'node_id'),
        orgname=pulumi.get(__ret__, 'orgname'),
        plan=pulumi.get(__ret__, 'plan'),
        repositories=pulumi.get(__ret__, 'repositories'),
        secret_scanning_enabled_for_new_repositories=pulumi.get(__ret__, 'secret_scanning_enabled_for_new_repositories'),
        secret_scanning_push_protection_enabled_for_new_repositories=pulumi.get(__ret__, 'secret_scanning_push_protection_enabled_for_new_repositories'),
        two_factor_requirement_enabled=pulumi.get(__ret__, 'two_factor_requirement_enabled'),
        users=pulumi.get(__ret__, 'users'),
        web_commit_signoff_required=pulumi.get(__ret__, 'web_commit_signoff_required'))


@_utilities.lift_output_func(get_organization)
def get_organization_output(ignore_archived_repos: Optional[pulumi.Input[Optional[bool]]] = None,
                            name: Optional[pulumi.Input[str]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetOrganizationResult]:
    """
    Use this data source to retrieve basic information about a GitHub Organization.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_github as github

    example = github.get_organization(name="github")
    ```


    :param bool ignore_archived_repos: Whether or not to include archived repos in the `repositories` list
    :param str name: The organization's public profile name
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetIssueLabelsResult',
    'AwaitableGetIssueLabelsResult',
    'get_issue_labels',
    'get_issue_labels_output',
]

@pulumi.output_type
class GetIssueLabelsResult:
    """
    A collection of values returned by getIssueLabels.
    """
    def __init__(__self__, id=None, labels=None, repository=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if labels and not isinstance(labels, list):
            raise TypeError("Expected argument 'labels' to be a list")
        pulumi.set(__self__, "labels", labels)
        if repository and not isinstance(repository, str):
            raise TypeError("Expected argument 'repository' to be a str")
        pulumi.set(__self__, "repository", repository)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def labels(self) -> Sequence['outputs.GetIssueLabelsLabelResult']:
        """
        The list of this repository's labels. Each element of `labels` has the following attributes:
        """
        return pulumi.get(self, "labels")

    @property
    @pulumi.getter
    def repository(self) -> str:
        return pulumi.get(self, "repository")


class AwaitableGetIssueLabelsResult(GetIssueLabelsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIssueLabelsResult(
            id=self.id,
            labels=self.labels,
            repository=self.repository)


def get_issue_labels(repository: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIssueLabelsResult:
    """
    Use this data source to retrieve the labels for a given repository.


    :param str repository: The name of the repository.
    """
    __args__ = dict()
    __args__['repository'] = repository
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('github:index/getIssueLabels:getIssueLabels', __args__, opts=opts, typ=GetIssueLabelsResult).value

    return AwaitableGetIssueLabelsResult(
        id=pulumi.get(__ret__, 'id'),
        labels=pulumi.get(__ret__, 'labels'),
        repository=pulumi.get(__ret__, 'repository'))


@_utilities.lift_output_func(get_issue_labels)
def get_issue_labels_output(repository: Optional[pulumi.Input[str]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetIssueLabelsResult]:
    """
    Use this data source to retrieve the labels for a given repository.


    :param str repository: The name of the repository.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['UserInvitationAccepterArgs', 'UserInvitationAccepter']

@pulumi.input_type
class UserInvitationAccepterArgs:
    def __init__(__self__, *,
                 allow_empty_id: Optional[pulumi.Input[bool]] = None,
                 invitation_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a UserInvitationAccepter resource.
        :param pulumi.Input[bool] allow_empty_id: Allow the ID to be unset. This will result in the resource being skipped when the ID is not set instead of returning an error.
        :param pulumi.Input[str] invitation_id: ID of the invitation to accept. Must be set when `allow_empty_id` is `false`.
        """
        if allow_empty_id is not None:
            pulumi.set(__self__, "allow_empty_id", allow_empty_id)
        if invitation_id is not None:
            pulumi.set(__self__, "invitation_id", invitation_id)

    @property
    @pulumi.getter(name="allowEmptyId")
    def allow_empty_id(self) -> Optional[pulumi.Input[bool]]:
        """
        Allow the ID to be unset. This will result in the resource being skipped when the ID is not set instead of returning an error.
        """
        return pulumi.get(self, "allow_empty_id")

    @allow_empty_id.setter
    def allow_empty_id(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "allow_empty_id", value)

    @property
    @pulumi.getter(name="invitationId")
    def invitation_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the invitation to accept. Must be set when `allow_empty_id` is `false`.
        """
        return pulumi.get(self, "invitation_id")

    @invitation_id.setter
    def invitation_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "invitation_id", value)


@pulumi.input_type
class _UserInvitationAccepterState:
    def __init__(__self__, *,
                 allow_empty_id: Optional[pulumi.Input[bool]] = None,
                 invitation_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering UserInvitationAccepter resources.
        :param pulumi.Input[bool] allow_empty_id: Allow the ID to be unset. This will result in the resource being skipped when the ID is not set instead of returning an error.
        :param pulumi.Input[str] invitation_id: ID of the invitation to accept. Must be set when `allow_empty_id` is `false`.
        """
        if allow_empty_id is not None:
            pulumi.set(__self__, "allow_empty_id", allow_empty_id)
        if invitation_id is not None:
            pulumi.set(__self__, "invitation_id", invitation_id)

    @property
    @pulumi.getter(name="allowEmptyId")
    def allow_empty_id(self) -> Optional[pulumi.Input[bool]]:
        """
        Allow the ID to be unset. This will result in the resource being skipped when the ID is not set instead of returning an error.
        """
        return pulumi.get(self, "allow_empty_id")

    @allow_empty_id.setter
    def allow_empty_id(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "allow_empty_id", value)

    @property
    @pulumi.getter(name="invitationId")
    def invitation_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of the invitation to accept. Must be set when `allow_empty_id` is `false`.
        """
        return pulumi.get(self, "invitation_id")

    @invitation_id.setter
    def invitation_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "invitation_id", value)


class UserInvitationAccepter(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_empty_id: Optional[pulumi.Input[bool]] = None,
                 invitation_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a resource to manage GitHub repository collaborator invitations.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        example = github.Repository("example", name="example-repo")
        example_repository_collaborator = github.RepositoryCollaborator("example",
            repository=example.name,
            username="example-username",
            permission="push")
        example_user_invitation_accepter = github.UserInvitationAccepter("example", invitation_id=example_repository_collaborator.invitation_id)
        ```

        ## Allowing empty invitation IDs

        Set `allow_empty_id` when using `for_each` over a list of `github_repository_collaborator.invitation_id`'s.

        This allows applying a module again when a new `RepositoryCollaborator` resource is added to the `for_each` loop.
        This is needed as the `github_repository_collaborator.invitation_id` will be empty after a state refresh when the invitation has been accepted.

        Note that when an invitation is accepted manually or by another tool between a state refresh and a `pulumi up` using that refreshed state,
        the plan will contain the invitation ID, but the apply will receive an HTTP 404 from the API since the invitation has already been accepted.

        This is tracked in #1157.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] allow_empty_id: Allow the ID to be unset. This will result in the resource being skipped when the ID is not set instead of returning an error.
        :param pulumi.Input[str] invitation_id: ID of the invitation to accept. Must be set when `allow_empty_id` is `false`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[UserInvitationAccepterArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a resource to manage GitHub repository collaborator invitations.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        example = github.Repository("example", name="example-repo")
        example_repository_collaborator = github.RepositoryCollaborator("example",
            repository=example.name,
            username="example-username",
            permission="push")
        example_user_invitation_accepter = github.UserInvitationAccepter("example", invitation_id=example_repository_collaborator.invitation_id)
        ```

        ## Allowing empty invitation IDs

        Set `allow_empty_id` when using `for_each` over a list of `github_repository_collaborator.invitation_id`'s.

        This allows applying a module again when a new `RepositoryCollaborator` resource is added to the `for_each` loop.
        This is needed as the `github_repository_collaborator.invitation_id` will be empty after a state refresh when the invitation has been accepted.

        Note that when an invitation is accepted manually or by another tool between a state refresh and a `pulumi up` using that refreshed state,
        the plan will contain the invitation ID, but the apply will receive an HTTP 404 from the API since the invitation has already been accepted.

        This is tracked in #1157.

        :param str resource_name: The name of the resource.
        :param UserInvitationAccepterArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(UserInvitationAccepterArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_empty_id: Optional[pulumi.Input[bool]] = None,
                 invitation_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = UserInvitationAccepterArgs.__new__(UserInvitationAccepterArgs)

            __props__.__dict__["allow_empty_id"] = allow_empty_id
            __props__.__dict__["invitation_id"] = invitation_id
        super(UserInvitationAccepter, __self__).__init__(
            'github:index/userInvitationAccepter:UserInvitationAccepter',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allow_empty_id: Optional[pulumi.Input[bool]] = None,
            invitation_id: Optional[pulumi.Input[str]] = None) -> 'UserInvitationAccepter':
        """
        Get an existing UserInvitationAccepter resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] allow_empty_id: Allow the ID to be unset. This will result in the resource being skipped when the ID is not set instead of returning an error.
        :param pulumi.Input[str] invitation_id: ID of the invitation to accept. Must be set when `allow_empty_id` is `false`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _UserInvitationAccepterState.__new__(_UserInvitationAccepterState)

        __props__.__dict__["allow_empty_id"] = allow_empty_id
        __props__.__dict__["invitation_id"] = invitation_id
        return UserInvitationAccepter(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allowEmptyId")
    def allow_empty_id(self) -> pulumi.Output[Optional[bool]]:
        """
        Allow the ID to be unset. This will result in the resource being skipped when the ID is not set instead of returning an error.
        """
        return pulumi.get(self, "allow_empty_id")

    @property
    @pulumi.getter(name="invitationId")
    def invitation_id(self) -> pulumi.Output[Optional[str]]:
        """
        ID of the invitation to accept. Must be set when `allow_empty_id` is `false`.
        """
        return pulumi.get(self, "invitation_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetRepositoryDeploymentBranchPoliciesResult',
    'AwaitableGetRepositoryDeploymentBranchPoliciesResult',
    'get_repository_deployment_branch_policies',
    'get_repository_deployment_branch_policies_output',
]

@pulumi.output_type
class GetRepositoryDeploymentBranchPoliciesResult:
    """
    A collection of values returned by getRepositoryDeploymentBranchPolicies.
    """
    def __init__(__self__, deployment_branch_policies=None, environment_name=None, id=None, repository=None):
        if deployment_branch_policies and not isinstance(deployment_branch_policies, list):
            raise TypeError("Expected argument 'deployment_branch_policies' to be a list")
        pulumi.set(__self__, "deployment_branch_policies", deployment_branch_policies)
        if environment_name and not isinstance(environment_name, str):
            raise TypeError("Expected argument 'environment_name' to be a str")
        pulumi.set(__self__, "environment_name", environment_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if repository and not isinstance(repository, str):
            raise TypeError("Expected argument 'repository' to be a str")
        pulumi.set(__self__, "repository", repository)

    @property
    @pulumi.getter(name="deploymentBranchPolicies")
    def deployment_branch_policies(self) -> Sequence['outputs.GetRepositoryDeploymentBranchPoliciesDeploymentBranchPolicyResult']:
        """
        The list of this repository / environment deployment policies. Each element of `deployment_branch_policies` has the following attributes:
        """
        return pulumi.get(self, "deployment_branch_policies")

    @property
    @pulumi.getter(name="environmentName")
    def environment_name(self) -> str:
        return pulumi.get(self, "environment_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def repository(self) -> str:
        return pulumi.get(self, "repository")


class AwaitableGetRepositoryDeploymentBranchPoliciesResult(GetRepositoryDeploymentBranchPoliciesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRepositoryDeploymentBranchPoliciesResult(
            deployment_branch_policies=self.deployment_branch_policies,
            environment_name=self.environment_name,
            id=self.id,
            repository=self.repository)


def get_repository_deployment_branch_policies(environment_name: Optional[str] = None,
                                              repository: Optional[str] = None,
                                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRepositoryDeploymentBranchPoliciesResult:
    """
    Use this data source to retrieve deployment branch policies for a repository / environment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_github as github

    example = github.get_repository_deployment_branch_policies(repository="example-repository",
        environment_name="env_name")
    ```


    :param str environment_name: Name of the environment to retrieve the deployment branch policies  from.
    :param str repository: Name of the repository to retrieve the deployment branch policies from.
    """
    __args__ = dict()
    __args__['environmentName'] = environment_name
    __args__['repository'] = repository
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('github:index/getRepositoryDeploymentBranchPolicies:getRepositoryDeploymentBranchPolicies', __args__, opts=opts, typ=GetRepositoryDeploymentBranchPoliciesResult).value

    return AwaitableGetRepositoryDeploymentBranchPoliciesResult(
        deployment_branch_policies=pulumi.get(__ret__, 'deployment_branch_policies'),
        environment_name=pulumi.get(__ret__, 'environment_name'),
        id=pulumi.get(__ret__, 'id'),
        repository=pulumi.get(__ret__, 'repository'))


@_utilities.lift_output_func(get_repository_deployment_branch_policies)
def get_repository_deployment_branch_policies_output(environment_name: Optional[pulumi.Input[str]] = None,
                                                     repository: Optional[pulumi.Input[str]] = None,
                                                     opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetRepositoryDeploymentBranchPoliciesResult]:
    """
    Use this data source to retrieve deployment branch policies for a repository / environment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_github as github

    example = github.get_repository_deployment_branch_policies(repository="example-repository",
        environment_name="env_name")
    ```


    :param str environment_name: Name of the environment to retrieve the deployment branch policies  from.
    :param str repository: Name of the repository to retrieve the deployment branch policies from.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RepositoryEnvironmentArgs', 'RepositoryEnvironment']

@pulumi.input_type
class RepositoryEnvironmentArgs:
    def __init__(__self__, *,
                 environment: pulumi.Input[str],
                 repository: pulumi.Input[str],
                 can_admins_bypass: Optional[pulumi.Input[bool]] = None,
                 deployment_branch_policy: Optional[pulumi.Input['RepositoryEnvironmentDeploymentBranchPolicyArgs']] = None,
                 prevent_self_review: Optional[pulumi.Input[bool]] = None,
                 reviewers: Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryEnvironmentReviewerArgs']]]] = None,
                 wait_timer: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a RepositoryEnvironment resource.
        :param pulumi.Input[str] environment: The name of the environment.
        :param pulumi.Input[str] repository: The repository of the environment.
        :param pulumi.Input[bool] can_admins_bypass: Can repository admins bypass the environment protections.  Defaults to `true`.
        :param pulumi.Input['RepositoryEnvironmentDeploymentBranchPolicyArgs'] deployment_branch_policy: The deployment branch policy configuration
        :param pulumi.Input[bool] prevent_self_review: Whether or not a user who created the job is prevented from approving their own job. Defaults to `false`.
        :param pulumi.Input[Sequence[pulumi.Input['RepositoryEnvironmentReviewerArgs']]] reviewers: The environment reviewers configuration.
        :param pulumi.Input[int] wait_timer: Amount of time to delay a job after the job is initially triggered.
        """
        pulumi.set(__self__, "environment", environment)
        pulumi.set(__self__, "repository", repository)
        if can_admins_bypass is not None:
            pulumi.set(__self__, "can_admins_bypass", can_admins_bypass)
        if deployment_branch_policy is not None:
            pulumi.set(__self__, "deployment_branch_policy", deployment_branch_policy)
        if prevent_self_review is not None:
            pulumi.set(__self__, "prevent_self_review", prevent_self_review)
        if reviewers is not None:
            pulumi.set(__self__, "reviewers", reviewers)
        if wait_timer is not None:
            pulumi.set(__self__, "wait_timer", wait_timer)

    @property
    @pulumi.getter
    def environment(self) -> pulumi.Input[str]:
        """
        The name of the environment.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: pulumi.Input[str]):
        pulumi.set(self, "environment", value)

    @property
    @pulumi.getter
    def repository(self) -> pulumi.Input[str]:
        """
        The repository of the environment.
        """
        return pulumi.get(self, "repository")

    @repository.setter
    def repository(self, value: pulumi.Input[str]):
        pulumi.set(self, "repository", value)

    @property
    @pulumi.getter(name="canAdminsBypass")
    def can_admins_bypass(self) -> Optional[pulumi.Input[bool]]:
        """
        Can repository admins bypass the environment protections.  Defaults to `true`.
        """
        return pulumi.get(self, "can_admins_bypass")

    @can_admins_bypass.setter
    def can_admins_bypass(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "can_admins_bypass", value)

    @property
    @pulumi.getter(name="deploymentBranchPolicy")
    def deployment_branch_policy(self) -> Optional[pulumi.Input['RepositoryEnvironmentDeploymentBranchPolicyArgs']]:
        """
        The deployment branch policy configuration
        """
        return pulumi.get(self, "deployment_branch_policy")

    @deployment_branch_policy.setter
    def deployment_branch_policy(self, value: Optional[pulumi.Input['RepositoryEnvironmentDeploymentBranchPolicyArgs']]):
        pulumi.set(self, "deployment_branch_policy", value)

    @property
    @pulumi.getter(name="preventSelfReview")
    def prevent_self_review(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether or not a user who created the job is prevented from approving their own job. Defaults to `false`.
        """
        return pulumi.get(self, "prevent_self_review")

    @prevent_self_review.setter
    def prevent_self_review(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "prevent_self_review", value)

    @property
    @pulumi.getter
    def reviewers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryEnvironmentReviewerArgs']]]]:
        """
        The environment reviewers configuration.
        """
        return pulumi.get(self, "reviewers")

    @reviewers.setter
    def reviewers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryEnvironmentReviewerArgs']]]]):
        pulumi.set(self, "reviewers", value)

    @property
    @pulumi.getter(name="waitTimer")
    def wait_timer(self) -> Optional[pulumi.Input[int]]:
        """
        Amount of time to delay a job after the job is initially triggered.
        """
        return pulumi.get(self, "wait_timer")

    @wait_timer.setter
    def wait_timer(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "wait_timer", value)


@pulumi.input_type
class _RepositoryEnvironmentState:
    def __init__(__self__, *,
                 can_admins_bypass: Optional[pulumi.Input[bool]] = None,
                 deployment_branch_policy: Optional[pulumi.Input['RepositoryEnvironmentDeploymentBranchPolicyArgs']] = None,
                 environment: Optional[pulumi.Input[str]] = None,
                 prevent_self_review: Optional[pulumi.Input[bool]] = None,
                 repository: Optional[pulumi.Input[str]] = None,
                 reviewers: Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryEnvironmentReviewerArgs']]]] = None,
                 wait_timer: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering RepositoryEnvironment resources.
        :param pulumi.Input[bool] can_admins_bypass: Can repository admins bypass the environment protections.  Defaults to `true`.
        :param pulumi.Input['RepositoryEnvironmentDeploymentBranchPolicyArgs'] deployment_branch_policy: The deployment branch policy configuration
        :param pulumi.Input[str] environment: The name of the environment.
        :param pulumi.Input[bool] prevent_self_review: Whether or not a user who created the job is prevented from approving their own job. Defaults to `false`.
        :param pulumi.Input[str] repository: The repository of the environment.
        :param pulumi.Input[Sequence[pulumi.Input['RepositoryEnvironmentReviewerArgs']]] reviewers: The environment reviewers configuration.
        :param pulumi.Input[int] wait_timer: Amount of time to delay a job after the job is initially triggered.
        """
        if can_admins_bypass is not None:
            pulumi.set(__self__, "can_admins_bypass", can_admins_bypass)
        if deployment_branch_policy is not None:
            pulumi.set(__self__, "deployment_branch_policy", deployment_branch_policy)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if prevent_self_review is not None:
            pulumi.set(__self__, "prevent_self_review", prevent_self_review)
        if repository is not None:
            pulumi.set(__self__, "repository", repository)
        if reviewers is not None:
            pulumi.set(__self__, "reviewers", reviewers)
        if wait_timer is not None:
            pulumi.set(__self__, "wait_timer", wait_timer)

    @property
    @pulumi.getter(name="canAdminsBypass")
    def can_admins_bypass(self) -> Optional[pulumi.Input[bool]]:
        """
        Can repository admins bypass the environment protections.  Defaults to `true`.
        """
        return pulumi.get(self, "can_admins_bypass")

    @can_admins_bypass.setter
    def can_admins_bypass(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "can_admins_bypass", value)

    @property
    @pulumi.getter(name="deploymentBranchPolicy")
    def deployment_branch_policy(self) -> Optional[pulumi.Input['RepositoryEnvironmentDeploymentBranchPolicyArgs']]:
        """
        The deployment branch policy configuration
        """
        return pulumi.get(self, "deployment_branch_policy")

    @deployment_branch_policy.setter
    def deployment_branch_policy(self, value: Optional[pulumi.Input['RepositoryEnvironmentDeploymentBranchPolicyArgs']]):
        pulumi.set(self, "deployment_branch_policy", value)

    @property
    @pulumi.getter
    def environment(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the environment.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "environment", value)

    @property
    @pulumi.getter(name="preventSelfReview")
    def prevent_self_review(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether or not a user who created the job is prevented from approving their own job. Defaults to `false`.
        """
        return pulumi.get(self, "prevent_self_review")

    @prevent_self_review.setter
    def prevent_self_review(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "prevent_self_review", value)

    @property
    @pulumi.getter
    def repository(self) -> Optional[pulumi.Input[str]]:
        """
        The repository of the environment.
        """
        return pulumi.get(self, "repository")

    @repository.setter
    def repository(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "repository", value)

    @property
    @pulumi.getter
    def reviewers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryEnvironmentReviewerArgs']]]]:
        """
        The environment reviewers configuration.
        """
        return pulumi.get(self, "reviewers")

    @reviewers.setter
    def reviewers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryEnvironmentReviewerArgs']]]]):
        pulumi.set(self, "reviewers", value)

    @property
    @pulumi.getter(name="waitTimer")
    def wait_timer(self) -> Optional[pulumi.Input[int]]:
        """
        Amount of time to delay a job after the job is initially triggered.
        """
        return pulumi.get(self, "wait_timer")

    @wait_timer.setter
    def wait_timer(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "wait_timer", value)


class RepositoryEnvironment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 can_admins_bypass: Optional[pulumi.Input[bool]] = None,
                 deployment_branch_policy: Optional[pulumi.Input[Union['RepositoryEnvironmentDeploymentBranchPolicyArgs', 'RepositoryEnvironmentDeploymentBranchPolicyArgsDict']]] = None,
                 environment: Optional[pulumi.Input[str]] = None,
                 prevent_self_review: Optional[pulumi.Input[bool]] = None,
                 repository: Optional[pulumi.Input[str]] = None,
                 reviewers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RepositoryEnvironmentReviewerArgs', 'RepositoryEnvironmentReviewerArgsDict']]]]] = None,
                 wait_timer: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        This resource allows you to create and manage environments for a GitHub repository.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        current = github.get_user(username="")
        example = github.Repository("example",
            name="A Repository Project",
            description="My awesome codebase")
        example_repository_environment = github.RepositoryEnvironment("example",
            environment="example",
            repository=example.name,
            prevent_self_review=True,
            reviewers=[{
                "users": [current.id],
            }],
            deployment_branch_policy={
                "protected_branches": True,
                "custom_branch_policies": False,
            })
        ```

        ## Import

        GitHub Repository Environment can be imported using an ID made up of `name` of the repository combined with the `environment` name of the environment, separated by a `:` character, e.g.

        ```sh
        $ pulumi import github:index/repositoryEnvironment:RepositoryEnvironment daily terraform:daily
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] can_admins_bypass: Can repository admins bypass the environment protections.  Defaults to `true`.
        :param pulumi.Input[Union['RepositoryEnvironmentDeploymentBranchPolicyArgs', 'RepositoryEnvironmentDeploymentBranchPolicyArgsDict']] deployment_branch_policy: The deployment branch policy configuration
        :param pulumi.Input[str] environment: The name of the environment.
        :param pulumi.Input[bool] prevent_self_review: Whether or not a user who created the job is prevented from approving their own job. Defaults to `false`.
        :param pulumi.Input[str] repository: The repository of the environment.
        :param pulumi.Input[Sequence[pulumi.Input[Union['RepositoryEnvironmentReviewerArgs', 'RepositoryEnvironmentReviewerArgsDict']]]] reviewers: The environment reviewers configuration.
        :param pulumi.Input[int] wait_timer: Amount of time to delay a job after the job is initially triggered.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RepositoryEnvironmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource allows you to create and manage environments for a GitHub repository.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        current = github.get_user(username="")
        example = github.Repository("example",
            name="A Repository Project",
            description="My awesome codebase")
        example_repository_environment = github.RepositoryEnvironment("example",
            environment="example",
            repository=example.name,
            prevent_self_review=True,
            reviewers=[{
                "users": [current.id],
            }],
            deployment_branch_policy={
                "protected_branches": True,
                "custom_branch_policies": False,
            })
        ```

        ## Import

        GitHub Repository Environment can be imported using an ID made up of `name` of the repository combined with the `environment` name of the environment, separated by a `:` character, e.g.

        ```sh
        $ pulumi import github:index/repositoryEnvironment:RepositoryEnvironment daily terraform:daily
        ```

        :param str resource_name: The name of the resource.
        :param RepositoryEnvironmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RepositoryEnvironmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 can_admins_bypass: Optional[pulumi.Input[bool]] = None,
                 deployment_branch_policy: Optional[pulumi.Input[Union['RepositoryEnvironmentDeploymentBranchPolicyArgs', 'RepositoryEnvironmentDeploymentBranchPolicyArgsDict']]] = None,
                 environment: Optional[pulumi.Input[str]] = None,
                 prevent_self_review: Optional[pulumi.Input[bool]] = None,
                 repository: Optional[pulumi.Input[str]] = None,
                 reviewers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RepositoryEnvironmentReviewerArgs', 'RepositoryEnvironmentReviewerArgsDict']]]]] = None,
                 wait_timer: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RepositoryEnvironmentArgs.__new__(RepositoryEnvironmentArgs)

            __props__.__dict__["can_admins_bypass"] = can_admins_bypass
            __props__.__dict__["deployment_branch_policy"] = deployment_branch_policy
            if environment is None and not opts.urn:
                raise TypeError("Missing required property 'environment'")
            __props__.__dict__["environment"] = environment
            __props__.__dict__["prevent_self_review"] = prevent_self_review
            if repository is None and not opts.urn:
                raise TypeError("Missing required property 'repository'")
            __props__.__dict__["repository"] = repository
            __props__.__dict__["reviewers"] = reviewers
            __props__.__dict__["wait_timer"] = wait_timer
        super(RepositoryEnvironment, __self__).__init__(
            'github:index/repositoryEnvironment:RepositoryEnvironment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            can_admins_bypass: Optional[pulumi.Input[bool]] = None,
            deployment_branch_policy: Optional[pulumi.Input[Union['RepositoryEnvironmentDeploymentBranchPolicyArgs', 'RepositoryEnvironmentDeploymentBranchPolicyArgsDict']]] = None,
            environment: Optional[pulumi.Input[str]] = None,
            prevent_self_review: Optional[pulumi.Input[bool]] = None,
            repository: Optional[pulumi.Input[str]] = None,
            reviewers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RepositoryEnvironmentReviewerArgs', 'RepositoryEnvironmentReviewerArgsDict']]]]] = None,
            wait_timer: Optional[pulumi.Input[int]] = None) -> 'RepositoryEnvironment':
        """
        Get an existing RepositoryEnvironment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] can_admins_bypass: Can repository admins bypass the environment protections.  Defaults to `true`.
        :param pulumi.Input[Union['RepositoryEnvironmentDeploymentBranchPolicyArgs', 'RepositoryEnvironmentDeploymentBranchPolicyArgsDict']] deployment_branch_policy: The deployment branch policy configuration
        :param pulumi.Input[str] environment: The name of the environment.
        :param pulumi.Input[bool] prevent_self_review: Whether or not a user who created the job is prevented from approving their own job. Defaults to `false`.
        :param pulumi.Input[str] repository: The repository of the environment.
        :param pulumi.Input[Sequence[pulumi.Input[Union['RepositoryEnvironmentReviewerArgs', 'RepositoryEnvironmentReviewerArgsDict']]]] reviewers: The environment reviewers configuration.
        :param pulumi.Input[int] wait_timer: Amount of time to delay a job after the job is initially triggered.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RepositoryEnvironmentState.__new__(_RepositoryEnvironmentState)

        __props__.__dict__["can_admins_bypass"] = can_admins_bypass
        __props__.__dict__["deployment_branch_policy"] = deployment_branch_policy
        __props__.__dict__["environment"] = environment
        __props__.__dict__["prevent_self_review"] = prevent_self_review
        __props__.__dict__["repository"] = repository
        __props__.__dict__["reviewers"] = reviewers
        __props__.__dict__["wait_timer"] = wait_timer
        return RepositoryEnvironment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="canAdminsBypass")
    def can_admins_bypass(self) -> pulumi.Output[Optional[bool]]:
        """
        Can repository admins bypass the environment protections.  Defaults to `true`.
        """
        return pulumi.get(self, "can_admins_bypass")

    @property
    @pulumi.getter(name="deploymentBranchPolicy")
    def deployment_branch_policy(self) -> pulumi.Output[Optional['outputs.RepositoryEnvironmentDeploymentBranchPolicy']]:
        """
        The deployment branch policy configuration
        """
        return pulumi.get(self, "deployment_branch_policy")

    @property
    @pulumi.getter
    def environment(self) -> pulumi.Output[str]:
        """
        The name of the environment.
        """
        return pulumi.get(self, "environment")

    @property
    @pulumi.getter(name="preventSelfReview")
    def prevent_self_review(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether or not a user who created the job is prevented from approving their own job. Defaults to `false`.
        """
        return pulumi.get(self, "prevent_self_review")

    @property
    @pulumi.getter
    def repository(self) -> pulumi.Output[str]:
        """
        The repository of the environment.
        """
        return pulumi.get(self, "repository")

    @property
    @pulumi.getter
    def reviewers(self) -> pulumi.Output[Optional[Sequence['outputs.RepositoryEnvironmentReviewer']]]:
        """
        The environment reviewers configuration.
        """
        return pulumi.get(self, "reviewers")

    @property
    @pulumi.getter(name="waitTimer")
    def wait_timer(self) -> pulumi.Output[Optional[int]]:
        """
        Amount of time to delay a job after the job is initially triggered.
        """
        return pulumi.get(self, "wait_timer")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RepositoryRulesetArgs', 'RepositoryRuleset']

@pulumi.input_type
class RepositoryRulesetArgs:
    def __init__(__self__, *,
                 enforcement: pulumi.Input[str],
                 rules: pulumi.Input['RepositoryRulesetRulesArgs'],
                 target: pulumi.Input[str],
                 bypass_actors: Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryRulesetBypassActorArgs']]]] = None,
                 conditions: Optional[pulumi.Input['RepositoryRulesetConditionsArgs']] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 repository: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a RepositoryRuleset resource.
        :param pulumi.Input[str] enforcement: (String) Possible values for Enforcement are `disabled`, `active`, `evaluate`. Note: `evaluate` is currently only supported for owners of type `organization`.
        :param pulumi.Input['RepositoryRulesetRulesArgs'] rules: (Block List, Min: 1, Max: 1) Rules within the ruleset. (see below for nested schema)
        :param pulumi.Input[str] target: (String) Possible values are `branch` and `tag`.
        :param pulumi.Input[Sequence[pulumi.Input['RepositoryRulesetBypassActorArgs']]] bypass_actors: (Block List) The actors that can bypass the rules in this ruleset. (see below for nested schema)
        :param pulumi.Input['RepositoryRulesetConditionsArgs'] conditions: (Block List, Max: 1) Parameters for a repository ruleset ref name condition. (see below for nested schema)
        :param pulumi.Input[str] name: (String) The name of the ruleset.
        :param pulumi.Input[str] repository: (String) Name of the repository to apply rulset to.
        """
        pulumi.set(__self__, "enforcement", enforcement)
        pulumi.set(__self__, "rules", rules)
        pulumi.set(__self__, "target", target)
        if bypass_actors is not None:
            pulumi.set(__self__, "bypass_actors", bypass_actors)
        if conditions is not None:
            pulumi.set(__self__, "conditions", conditions)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if repository is not None:
            pulumi.set(__self__, "repository", repository)

    @property
    @pulumi.getter
    def enforcement(self) -> pulumi.Input[str]:
        """
        (String) Possible values for Enforcement are `disabled`, `active`, `evaluate`. Note: `evaluate` is currently only supported for owners of type `organization`.
        """
        return pulumi.get(self, "enforcement")

    @enforcement.setter
    def enforcement(self, value: pulumi.Input[str]):
        pulumi.set(self, "enforcement", value)

    @property
    @pulumi.getter
    def rules(self) -> pulumi.Input['RepositoryRulesetRulesArgs']:
        """
        (Block List, Min: 1, Max: 1) Rules within the ruleset. (see below for nested schema)
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: pulumi.Input['RepositoryRulesetRulesArgs']):
        pulumi.set(self, "rules", value)

    @property
    @pulumi.getter
    def target(self) -> pulumi.Input[str]:
        """
        (String) Possible values are `branch` and `tag`.
        """
        return pulumi.get(self, "target")

    @target.setter
    def target(self, value: pulumi.Input[str]):
        pulumi.set(self, "target", value)

    @property
    @pulumi.getter(name="bypassActors")
    def bypass_actors(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryRulesetBypassActorArgs']]]]:
        """
        (Block List) The actors that can bypass the rules in this ruleset. (see below for nested schema)
        """
        return pulumi.get(self, "bypass_actors")

    @bypass_actors.setter
    def bypass_actors(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryRulesetBypassActorArgs']]]]):
        pulumi.set(self, "bypass_actors", value)

    @property
    @pulumi.getter
    def conditions(self) -> Optional[pulumi.Input['RepositoryRulesetConditionsArgs']]:
        """
        (Block List, Max: 1) Parameters for a repository ruleset ref name condition. (see below for nested schema)
        """
        return pulumi.get(self, "conditions")

    @conditions.setter
    def conditions(self, value: Optional[pulumi.Input['RepositoryRulesetConditionsArgs']]):
        pulumi.set(self, "conditions", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        (String) The name of the ruleset.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def repository(self) -> Optional[pulumi.Input[str]]:
        """
        (String) Name of the repository to apply rulset to.
        """
        return pulumi.get(self, "repository")

    @repository.setter
    def repository(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "repository", value)


@pulumi.input_type
class _RepositoryRulesetState:
    def __init__(__self__, *,
                 bypass_actors: Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryRulesetBypassActorArgs']]]] = None,
                 conditions: Optional[pulumi.Input['RepositoryRulesetConditionsArgs']] = None,
                 enforcement: Optional[pulumi.Input[str]] = None,
                 etag: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 node_id: Optional[pulumi.Input[str]] = None,
                 repository: Optional[pulumi.Input[str]] = None,
                 rules: Optional[pulumi.Input['RepositoryRulesetRulesArgs']] = None,
                 ruleset_id: Optional[pulumi.Input[int]] = None,
                 target: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering RepositoryRuleset resources.
        :param pulumi.Input[Sequence[pulumi.Input['RepositoryRulesetBypassActorArgs']]] bypass_actors: (Block List) The actors that can bypass the rules in this ruleset. (see below for nested schema)
        :param pulumi.Input['RepositoryRulesetConditionsArgs'] conditions: (Block List, Max: 1) Parameters for a repository ruleset ref name condition. (see below for nested schema)
        :param pulumi.Input[str] enforcement: (String) Possible values for Enforcement are `disabled`, `active`, `evaluate`. Note: `evaluate` is currently only supported for owners of type `organization`.
        :param pulumi.Input[str] etag: (String)
        :param pulumi.Input[str] name: (String) The name of the ruleset.
        :param pulumi.Input[str] node_id: (String) GraphQL global node id for use with v4 API.
        :param pulumi.Input[str] repository: (String) Name of the repository to apply rulset to.
        :param pulumi.Input['RepositoryRulesetRulesArgs'] rules: (Block List, Min: 1, Max: 1) Rules within the ruleset. (see below for nested schema)
        :param pulumi.Input[int] ruleset_id: (Number) GitHub ID for the ruleset.
        :param pulumi.Input[str] target: (String) Possible values are `branch` and `tag`.
        """
        if bypass_actors is not None:
            pulumi.set(__self__, "bypass_actors", bypass_actors)
        if conditions is not None:
            pulumi.set(__self__, "conditions", conditions)
        if enforcement is not None:
            pulumi.set(__self__, "enforcement", enforcement)
        if etag is not None:
            pulumi.set(__self__, "etag", etag)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if node_id is not None:
            pulumi.set(__self__, "node_id", node_id)
        if repository is not None:
            pulumi.set(__self__, "repository", repository)
        if rules is not None:
            pulumi.set(__self__, "rules", rules)
        if ruleset_id is not None:
            pulumi.set(__self__, "ruleset_id", ruleset_id)
        if target is not None:
            pulumi.set(__self__, "target", target)

    @property
    @pulumi.getter(name="bypassActors")
    def bypass_actors(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryRulesetBypassActorArgs']]]]:
        """
        (Block List) The actors that can bypass the rules in this ruleset. (see below for nested schema)
        """
        return pulumi.get(self, "bypass_actors")

    @bypass_actors.setter
    def bypass_actors(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RepositoryRulesetBypassActorArgs']]]]):
        pulumi.set(self, "bypass_actors", value)

    @property
    @pulumi.getter
    def conditions(self) -> Optional[pulumi.Input['RepositoryRulesetConditionsArgs']]:
        """
        (Block List, Max: 1) Parameters for a repository ruleset ref name condition. (see below for nested schema)
        """
        return pulumi.get(self, "conditions")

    @conditions.setter
    def conditions(self, value: Optional[pulumi.Input['RepositoryRulesetConditionsArgs']]):
        pulumi.set(self, "conditions", value)

    @property
    @pulumi.getter
    def enforcement(self) -> Optional[pulumi.Input[str]]:
        """
        (String) Possible values for Enforcement are `disabled`, `active`, `evaluate`. Note: `evaluate` is currently only supported for owners of type `organization`.
        """
        return pulumi.get(self, "enforcement")

    @enforcement.setter
    def enforcement(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "enforcement", value)

    @property
    @pulumi.getter
    def etag(self) -> Optional[pulumi.Input[str]]:
        """
        (String)
        """
        return pulumi.get(self, "etag")

    @etag.setter
    def etag(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "etag", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        (String) The name of the ruleset.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="nodeId")
    def node_id(self) -> Optional[pulumi.Input[str]]:
        """
        (String) GraphQL global node id for use with v4 API.
        """
        return pulumi.get(self, "node_id")

    @node_id.setter
    def node_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "node_id", value)

    @property
    @pulumi.getter
    def repository(self) -> Optional[pulumi.Input[str]]:
        """
        (String) Name of the repository to apply rulset to.
        """
        return pulumi.get(self, "repository")

    @repository.setter
    def repository(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "repository", value)

    @property
    @pulumi.getter
    def rules(self) -> Optional[pulumi.Input['RepositoryRulesetRulesArgs']]:
        """
        (Block List, Min: 1, Max: 1) Rules within the ruleset. (see below for nested schema)
        """
        return pulumi.get(self, "rules")

    @rules.setter
    def rules(self, value: Optional[pulumi.Input['RepositoryRulesetRulesArgs']]):
        pulumi.set(self, "rules", value)

    @property
    @pulumi.getter(name="rulesetId")
    def ruleset_id(self) -> Optional[pulumi.Input[int]]:
        """
        (Number) GitHub ID for the ruleset.
        """
        return pulumi.get(self, "ruleset_id")

    @ruleset_id.setter
    def ruleset_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "ruleset_id", value)

    @property
    @pulumi.getter
    def target(self) -> Optional[pulumi.Input[str]]:
        """
        (String) Possible values are `branch` and `tag`.
        """
        return pulumi.get(self, "target")

    @target.setter
    def target(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "target", value)


class RepositoryRuleset(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bypass_actors: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RepositoryRulesetBypassActorArgs', 'RepositoryRulesetBypassActorArgsDict']]]]] = None,
                 conditions: Optional[pulumi.Input[Union['RepositoryRulesetConditionsArgs', 'RepositoryRulesetConditionsArgsDict']]] = None,
                 enforcement: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 repository: Optional[pulumi.Input[str]] = None,
                 rules: Optional[pulumi.Input[Union['RepositoryRulesetRulesArgs', 'RepositoryRulesetRulesArgsDict']]] = None,
                 target: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Creates a GitHub repository ruleset.

        This resource allows you to create and manage rulesets on the repository level. When applied, a new ruleset will be created. When destroyed, that ruleset will be removed.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        example = github.Repository("example",
            name="example",
            description="Example repository")
        example_repository_ruleset = github.RepositoryRuleset("example",
            name="example",
            repository=example.name,
            target="branch",
            enforcement="active",
            conditions={
                "ref_name": {
                    "includes": ["~ALL"],
                    "excludes": [],
                },
            },
            bypass_actors=[{
                "actor_id": 13473,
                "actor_type": "Integration",
                "bypass_mode": "always",
            }],
            rules={
                "creation": True,
                "update": True,
                "deletion": True,
                "required_linear_history": True,
                "required_signatures": True,
                "required_deployments": {
                    "required_deployment_environments": ["test"],
                },
            })
        ```

        ## Import

        GitHub Repository Rulesets can be imported using the GitHub repository name and ruleset ID e.g.

        ```sh
        $ pulumi import github:index/repositoryRuleset:RepositoryRuleset example example:12345`
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['RepositoryRulesetBypassActorArgs', 'RepositoryRulesetBypassActorArgsDict']]]] bypass_actors: (Block List) The actors that can bypass the rules in this ruleset. (see below for nested schema)
        :param pulumi.Input[Union['RepositoryRulesetConditionsArgs', 'RepositoryRulesetConditionsArgsDict']] conditions: (Block List, Max: 1) Parameters for a repository ruleset ref name condition. (see below for nested schema)
        :param pulumi.Input[str] enforcement: (String) Possible values for Enforcement are `disabled`, `active`, `evaluate`. Note: `evaluate` is currently only supported for owners of type `organization`.
        :param pulumi.Input[str] name: (String) The name of the ruleset.
        :param pulumi.Input[str] repository: (String) Name of the repository to apply rulset to.
        :param pulumi.Input[Union['RepositoryRulesetRulesArgs', 'RepositoryRulesetRulesArgsDict']] rules: (Block List, Min: 1, Max: 1) Rules within the ruleset. (see below for nested schema)
        :param pulumi.Input[str] target: (String) Possible values are `branch` and `tag`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RepositoryRulesetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a GitHub repository ruleset.

        This resource allows you to create and manage rulesets on the repository level. When applied, a new ruleset will be created. When destroyed, that ruleset will be removed.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        example = github.Repository("example",
            name="example",
            description="Example repository")
        example_repository_ruleset = github.RepositoryRuleset("example",
            name="example",
            repository=example.name,
            target="branch",
            enforcement="active",
            conditions={
                "ref_name": {
                    "includes": ["~ALL"],
                    "excludes": [],
                },
            },
            bypass_actors=[{
                "actor_id": 13473,
                "actor_type": "Integration",
                "bypass_mode": "always",
            }],
            rules={
                "creation": True,
                "update": True,
                "deletion": True,
                "required_linear_history": True,
                "required_signatures": True,
                "required_deployments": {
                    "required_deployment_environments": ["test"],
                },
            })
        ```

        ## Import

        GitHub Repository Rulesets can be imported using the GitHub repository name and ruleset ID e.g.

        ```sh
        $ pulumi import github:index/repositoryRuleset:RepositoryRuleset example example:12345`
        ```

        :param str resource_name: The name of the resource.
        :param RepositoryRulesetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RepositoryRulesetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bypass_actors: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RepositoryRulesetBypassActorArgs', 'RepositoryRulesetBypassActorArgsDict']]]]] = None,
                 conditions: Optional[pulumi.Input[Union['RepositoryRulesetConditionsArgs', 'RepositoryRulesetConditionsArgsDict']]] = None,
                 enforcement: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 repository: Optional[pulumi.Input[str]] = None,
                 rules: Optional[pulumi.Input[Union['RepositoryRulesetRulesArgs', 'RepositoryRulesetRulesArgsDict']]] = None,
                 target: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RepositoryRulesetArgs.__new__(RepositoryRulesetArgs)

            __props__.__dict__["bypass_actors"] = bypass_actors
            __props__.__dict__["conditions"] = conditions
            if enforcement is None and not opts.urn:
                raise TypeError("Missing required property 'enforcement'")
            __props__.__dict__["enforcement"] = enforcement
            __props__.__dict__["name"] = name
            __props__.__dict__["repository"] = repository
            if rules is None and not opts.urn:
                raise TypeError("Missing required property 'rules'")
            __props__.__dict__["rules"] = rules
            if target is None and not opts.urn:
                raise TypeError("Missing required property 'target'")
            __props__.__dict__["target"] = target
            __props__.__dict__["etag"] = None
            __props__.__dict__["node_id"] = None
            __props__.__dict__["ruleset_id"] = None
        super(RepositoryRuleset, __self__).__init__(
            'github:index/repositoryRuleset:RepositoryRuleset',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bypass_actors: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RepositoryRulesetBypassActorArgs', 'RepositoryRulesetBypassActorArgsDict']]]]] = None,
            conditions: Optional[pulumi.Input[Union['RepositoryRulesetConditionsArgs', 'RepositoryRulesetConditionsArgsDict']]] = None,
            enforcement: Optional[pulumi.Input[str]] = None,
            etag: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            node_id: Optional[pulumi.Input[str]] = None,
            repository: Optional[pulumi.Input[str]] = None,
            rules: Optional[pulumi.Input[Union['RepositoryRulesetRulesArgs', 'RepositoryRulesetRulesArgsDict']]] = None,
            ruleset_id: Optional[pulumi.Input[int]] = None,
            target: Optional[pulumi.Input[str]] = None) -> 'RepositoryRuleset':
        """
        Get an existing RepositoryRuleset resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['RepositoryRulesetBypassActorArgs', 'RepositoryRulesetBypassActorArgsDict']]]] bypass_actors: (Block List) The actors that can bypass the rules in this ruleset. (see below for nested schema)
        :param pulumi.Input[Union['RepositoryRulesetConditionsArgs', 'RepositoryRulesetConditionsArgsDict']] conditions: (Block List, Max: 1) Parameters for a repository ruleset ref name condition. (see below for nested schema)
        :param pulumi.Input[str] enforcement: (String) Possible values for Enforcement are `disabled`, `active`, `evaluate`. Note: `evaluate` is currently only supported for owners of type `organization`.
        :param pulumi.Input[str] etag: (String)
        :param pulumi.Input[str] name: (String) The name of the ruleset.
        :param pulumi.Input[str] node_id: (String) GraphQL global node id for use with v4 API.
        :param pulumi.Input[str] repository: (String) Name of the repository to apply rulset to.
        :param pulumi.Input[Union['RepositoryRulesetRulesArgs', 'RepositoryRulesetRulesArgsDict']] rules: (Block List, Min: 1, Max: 1) Rules within the ruleset. (see below for nested schema)
        :param pulumi.Input[int] ruleset_id: (Number) GitHub ID for the ruleset.
        :param pulumi.Input[str] target: (String) Possible values are `branch` and `tag`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RepositoryRulesetState.__new__(_RepositoryRulesetState)

        __props__.__dict__["bypass_actors"] = bypass_actors
        __props__.__dict__["conditions"] = conditions
        __props__.__dict__["enforcement"] = enforcement
        __props__.__dict__["etag"] = etag
        __props__.__dict__["name"] = name
        __props__.__dict__["node_id"] = node_id
        __props__.__dict__["repository"] = repository
        __props__.__dict__["rules"] = rules
        __props__.__dict__["ruleset_id"] = ruleset_id
        __props__.__dict__["target"] = target
        return RepositoryRuleset(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="bypassActors")
    def bypass_actors(self) -> pulumi.Output[Optional[Sequence['outputs.RepositoryRulesetBypassActor']]]:
        """
        (Block List) The actors that can bypass the rules in this ruleset. (see below for nested schema)
        """
        return pulumi.get(self, "bypass_actors")

    @property
    @pulumi.getter
    def conditions(self) -> pulumi.Output[Optional['outputs.RepositoryRulesetConditions']]:
        """
        (Block List, Max: 1) Parameters for a repository ruleset ref name condition. (see below for nested schema)
        """
        return pulumi.get(self, "conditions")

    @property
    @pulumi.getter
    def enforcement(self) -> pulumi.Output[str]:
        """
        (String) Possible values for Enforcement are `disabled`, `active`, `evaluate`. Note: `evaluate` is currently only supported for owners of type `organization`.
        """
        return pulumi.get(self, "enforcement")

    @property
    @pulumi.getter
    def etag(self) -> pulumi.Output[str]:
        """
        (String)
        """
        return pulumi.get(self, "etag")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        (String) The name of the ruleset.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nodeId")
    def node_id(self) -> pulumi.Output[str]:
        """
        (String) GraphQL global node id for use with v4 API.
        """
        return pulumi.get(self, "node_id")

    @property
    @pulumi.getter
    def repository(self) -> pulumi.Output[Optional[str]]:
        """
        (String) Name of the repository to apply rulset to.
        """
        return pulumi.get(self, "repository")

    @property
    @pulumi.getter
    def rules(self) -> pulumi.Output['outputs.RepositoryRulesetRules']:
        """
        (Block List, Min: 1, Max: 1) Rules within the ruleset. (see below for nested schema)
        """
        return pulumi.get(self, "rules")

    @property
    @pulumi.getter(name="rulesetId")
    def ruleset_id(self) -> pulumi.Output[int]:
        """
        (Number) GitHub ID for the ruleset.
        """
        return pulumi.get(self, "ruleset_id")

    @property
    @pulumi.getter
    def target(self) -> pulumi.Output[str]:
        """
        (String) Possible values are `branch` and `tag`.
        """
        return pulumi.get(self, "target")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['RepositoryAutolinkReferenceArgs', 'RepositoryAutolinkReference']

@pulumi.input_type
class RepositoryAutolinkReferenceArgs:
    def __init__(__self__, *,
                 key_prefix: pulumi.Input[str],
                 repository: pulumi.Input[str],
                 target_url_template: pulumi.Input[str],
                 is_alphanumeric: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a RepositoryAutolinkReference resource.
        :param pulumi.Input[str] key_prefix: This prefix appended by a number will generate a link any time it is found in an issue, pull request, or commit.
        :param pulumi.Input[str] repository: The repository of the autolink reference.
        :param pulumi.Input[str] target_url_template: The template of the target URL used for the links; must be a valid URL and contain `<num>` for the reference number
        :param pulumi.Input[bool] is_alphanumeric: Whether this autolink reference matches alphanumeric characters. If false, this autolink reference only matches numeric characters. Default is true.
        """
        pulumi.set(__self__, "key_prefix", key_prefix)
        pulumi.set(__self__, "repository", repository)
        pulumi.set(__self__, "target_url_template", target_url_template)
        if is_alphanumeric is not None:
            pulumi.set(__self__, "is_alphanumeric", is_alphanumeric)

    @property
    @pulumi.getter(name="keyPrefix")
    def key_prefix(self) -> pulumi.Input[str]:
        """
        This prefix appended by a number will generate a link any time it is found in an issue, pull request, or commit.
        """
        return pulumi.get(self, "key_prefix")

    @key_prefix.setter
    def key_prefix(self, value: pulumi.Input[str]):
        pulumi.set(self, "key_prefix", value)

    @property
    @pulumi.getter
    def repository(self) -> pulumi.Input[str]:
        """
        The repository of the autolink reference.
        """
        return pulumi.get(self, "repository")

    @repository.setter
    def repository(self, value: pulumi.Input[str]):
        pulumi.set(self, "repository", value)

    @property
    @pulumi.getter(name="targetUrlTemplate")
    def target_url_template(self) -> pulumi.Input[str]:
        """
        The template of the target URL used for the links; must be a valid URL and contain `<num>` for the reference number
        """
        return pulumi.get(self, "target_url_template")

    @target_url_template.setter
    def target_url_template(self, value: pulumi.Input[str]):
        pulumi.set(self, "target_url_template", value)

    @property
    @pulumi.getter(name="isAlphanumeric")
    def is_alphanumeric(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether this autolink reference matches alphanumeric characters. If false, this autolink reference only matches numeric characters. Default is true.
        """
        return pulumi.get(self, "is_alphanumeric")

    @is_alphanumeric.setter
    def is_alphanumeric(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_alphanumeric", value)


@pulumi.input_type
class _RepositoryAutolinkReferenceState:
    def __init__(__self__, *,
                 etag: Optional[pulumi.Input[str]] = None,
                 is_alphanumeric: Optional[pulumi.Input[bool]] = None,
                 key_prefix: Optional[pulumi.Input[str]] = None,
                 repository: Optional[pulumi.Input[str]] = None,
                 target_url_template: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering RepositoryAutolinkReference resources.
        :param pulumi.Input[str] etag: An etag representing the autolink reference object.
        :param pulumi.Input[bool] is_alphanumeric: Whether this autolink reference matches alphanumeric characters. If false, this autolink reference only matches numeric characters. Default is true.
        :param pulumi.Input[str] key_prefix: This prefix appended by a number will generate a link any time it is found in an issue, pull request, or commit.
        :param pulumi.Input[str] repository: The repository of the autolink reference.
        :param pulumi.Input[str] target_url_template: The template of the target URL used for the links; must be a valid URL and contain `<num>` for the reference number
        """
        if etag is not None:
            pulumi.set(__self__, "etag", etag)
        if is_alphanumeric is not None:
            pulumi.set(__self__, "is_alphanumeric", is_alphanumeric)
        if key_prefix is not None:
            pulumi.set(__self__, "key_prefix", key_prefix)
        if repository is not None:
            pulumi.set(__self__, "repository", repository)
        if target_url_template is not None:
            pulumi.set(__self__, "target_url_template", target_url_template)

    @property
    @pulumi.getter
    def etag(self) -> Optional[pulumi.Input[str]]:
        """
        An etag representing the autolink reference object.
        """
        return pulumi.get(self, "etag")

    @etag.setter
    def etag(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "etag", value)

    @property
    @pulumi.getter(name="isAlphanumeric")
    def is_alphanumeric(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether this autolink reference matches alphanumeric characters. If false, this autolink reference only matches numeric characters. Default is true.
        """
        return pulumi.get(self, "is_alphanumeric")

    @is_alphanumeric.setter
    def is_alphanumeric(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_alphanumeric", value)

    @property
    @pulumi.getter(name="keyPrefix")
    def key_prefix(self) -> Optional[pulumi.Input[str]]:
        """
        This prefix appended by a number will generate a link any time it is found in an issue, pull request, or commit.
        """
        return pulumi.get(self, "key_prefix")

    @key_prefix.setter
    def key_prefix(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key_prefix", value)

    @property
    @pulumi.getter
    def repository(self) -> Optional[pulumi.Input[str]]:
        """
        The repository of the autolink reference.
        """
        return pulumi.get(self, "repository")

    @repository.setter
    def repository(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "repository", value)

    @property
    @pulumi.getter(name="targetUrlTemplate")
    def target_url_template(self) -> Optional[pulumi.Input[str]]:
        """
        The template of the target URL used for the links; must be a valid URL and contain `<num>` for the reference number
        """
        return pulumi.get(self, "target_url_template")

    @target_url_template.setter
    def target_url_template(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "target_url_template", value)


class RepositoryAutolinkReference(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 is_alphanumeric: Optional[pulumi.Input[bool]] = None,
                 key_prefix: Optional[pulumi.Input[str]] = None,
                 repository: Optional[pulumi.Input[str]] = None,
                 target_url_template: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource allows you to create and manage an autolink reference for a single repository.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        repo = github.Repository("repo",
            name="my-repo",
            description="GitHub repo managed by Terraform",
            private=False)
        autolink = github.RepositoryAutolinkReference("autolink",
            repository=repo.name,
            key_prefix="TICKET-",
            target_url_template="https://example.com/TICKET?query=<num>")
        ```

        ## Import

        ### Import by key prefix

        ```sh
        $ pulumi import github:index/repositoryAutolinkReference:RepositoryAutolinkReference auto oof/OOF-
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] is_alphanumeric: Whether this autolink reference matches alphanumeric characters. If false, this autolink reference only matches numeric characters. Default is true.
        :param pulumi.Input[str] key_prefix: This prefix appended by a number will generate a link any time it is found in an issue, pull request, or commit.
        :param pulumi.Input[str] repository: The repository of the autolink reference.
        :param pulumi.Input[str] target_url_template: The template of the target URL used for the links; must be a valid URL and contain `<num>` for the reference number
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RepositoryAutolinkReferenceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource allows you to create and manage an autolink reference for a single repository.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        repo = github.Repository("repo",
            name="my-repo",
            description="GitHub repo managed by Terraform",
            private=False)
        autolink = github.RepositoryAutolinkReference("autolink",
            repository=repo.name,
            key_prefix="TICKET-",
            target_url_template="https://example.com/TICKET?query=<num>")
        ```

        ## Import

        ### Import by key prefix

        ```sh
        $ pulumi import github:index/repositoryAutolinkReference:RepositoryAutolinkReference auto oof/OOF-
        ```

        :param str resource_name: The name of the resource.
        :param RepositoryAutolinkReferenceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RepositoryAutolinkReferenceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 is_alphanumeric: Optional[pulumi.Input[bool]] = None,
                 key_prefix: Optional[pulumi.Input[str]] = None,
                 repository: Optional[pulumi.Input[str]] = None,
                 target_url_template: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RepositoryAutolinkReferenceArgs.__new__(RepositoryAutolinkReferenceArgs)

            __props__.__dict__["is_alphanumeric"] = is_alphanumeric
            if key_prefix is None and not opts.urn:
                raise TypeError("Missing required property 'key_prefix'")
            __props__.__dict__["key_prefix"] = key_prefix
            if repository is None and not opts.urn:
                raise TypeError("Missing required property 'repository'")
            __props__.__dict__["repository"] = repository
            if target_url_template is None and not opts.urn:
                raise TypeError("Missing required property 'target_url_template'")
            __props__.__dict__["target_url_template"] = target_url_template
            __props__.__dict__["etag"] = None
        super(RepositoryAutolinkReference, __self__).__init__(
            'github:index/repositoryAutolinkReference:RepositoryAutolinkReference',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            etag: Optional[pulumi.Input[str]] = None,
            is_alphanumeric: Optional[pulumi.Input[bool]] = None,
            key_prefix: Optional[pulumi.Input[str]] = None,
            repository: Optional[pulumi.Input[str]] = None,
            target_url_template: Optional[pulumi.Input[str]] = None) -> 'RepositoryAutolinkReference':
        """
        Get an existing RepositoryAutolinkReference resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] etag: An etag representing the autolink reference object.
        :param pulumi.Input[bool] is_alphanumeric: Whether this autolink reference matches alphanumeric characters. If false, this autolink reference only matches numeric characters. Default is true.
        :param pulumi.Input[str] key_prefix: This prefix appended by a number will generate a link any time it is found in an issue, pull request, or commit.
        :param pulumi.Input[str] repository: The repository of the autolink reference.
        :param pulumi.Input[str] target_url_template: The template of the target URL used for the links; must be a valid URL and contain `<num>` for the reference number
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RepositoryAutolinkReferenceState.__new__(_RepositoryAutolinkReferenceState)

        __props__.__dict__["etag"] = etag
        __props__.__dict__["is_alphanumeric"] = is_alphanumeric
        __props__.__dict__["key_prefix"] = key_prefix
        __props__.__dict__["repository"] = repository
        __props__.__dict__["target_url_template"] = target_url_template
        return RepositoryAutolinkReference(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def etag(self) -> pulumi.Output[str]:
        """
        An etag representing the autolink reference object.
        """
        return pulumi.get(self, "etag")

    @property
    @pulumi.getter(name="isAlphanumeric")
    def is_alphanumeric(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether this autolink reference matches alphanumeric characters. If false, this autolink reference only matches numeric characters. Default is true.
        """
        return pulumi.get(self, "is_alphanumeric")

    @property
    @pulumi.getter(name="keyPrefix")
    def key_prefix(self) -> pulumi.Output[str]:
        """
        This prefix appended by a number will generate a link any time it is found in an issue, pull request, or commit.
        """
        return pulumi.get(self, "key_prefix")

    @property
    @pulumi.getter
    def repository(self) -> pulumi.Output[str]:
        """
        The repository of the autolink reference.
        """
        return pulumi.get(self, "repository")

    @property
    @pulumi.getter(name="targetUrlTemplate")
    def target_url_template(self) -> pulumi.Output[str]:
        """
        The template of the target URL used for the links; must be a valid URL and contain `<num>` for the reference number
        """
        return pulumi.get(self, "target_url_template")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetCollaboratorsResult',
    'AwaitableGetCollaboratorsResult',
    'get_collaborators',
    'get_collaborators_output',
]

@pulumi.output_type
class GetCollaboratorsResult:
    """
    A collection of values returned by getCollaborators.
    """
    def __init__(__self__, affiliation=None, collaborators=None, id=None, owner=None, repository=None):
        if affiliation and not isinstance(affiliation, str):
            raise TypeError("Expected argument 'affiliation' to be a str")
        pulumi.set(__self__, "affiliation", affiliation)
        if collaborators and not isinstance(collaborators, list):
            raise TypeError("Expected argument 'collaborators' to be a list")
        pulumi.set(__self__, "collaborators", collaborators)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if repository and not isinstance(repository, str):
            raise TypeError("Expected argument 'repository' to be a str")
        pulumi.set(__self__, "repository", repository)

    @property
    @pulumi.getter
    def affiliation(self) -> Optional[str]:
        return pulumi.get(self, "affiliation")

    @property
    @pulumi.getter
    def collaborators(self) -> Sequence['outputs.GetCollaboratorsCollaboratorResult']:
        """
        An Array of GitHub collaborators.  Each `collaborator` block consists of the fields documented below.
        """
        return pulumi.get(self, "collaborators")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def owner(self) -> str:
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter
    def repository(self) -> str:
        return pulumi.get(self, "repository")


class AwaitableGetCollaboratorsResult(GetCollaboratorsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCollaboratorsResult(
            affiliation=self.affiliation,
            collaborators=self.collaborators,
            id=self.id,
            owner=self.owner,
            repository=self.repository)


def get_collaborators(affiliation: Optional[str] = None,
                      owner: Optional[str] = None,
                      repository: Optional[str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCollaboratorsResult:
    """
    Use this data source to retrieve the collaborators for a given repository.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_github as github

    test = github.get_collaborators(owner="example_owner",
        repository="example_repository")
    ```


    :param str affiliation: Filter collaborators returned by their affiliation. Can be one of: `outside`, `direct`, `all`.  Defaults to `all`.
    :param str owner: The organization that owns the repository.
    :param str repository: The name of the repository.
    """
    __args__ = dict()
    __args__['affiliation'] = affiliation
    __args__['owner'] = owner
    __args__['repository'] = repository
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('github:index/getCollaborators:getCollaborators', __args__, opts=opts, typ=GetCollaboratorsResult).value

    return AwaitableGetCollaboratorsResult(
        affiliation=pulumi.get(__ret__, 'affiliation'),
        collaborators=pulumi.get(__ret__, 'collaborators'),
        id=pulumi.get(__ret__, 'id'),
        owner=pulumi.get(__ret__, 'owner'),
        repository=pulumi.get(__ret__, 'repository'))


@_utilities.lift_output_func(get_collaborators)
def get_collaborators_output(affiliation: Optional[pulumi.Input[Optional[str]]] = None,
                             owner: Optional[pulumi.Input[str]] = None,
                             repository: Optional[pulumi.Input[str]] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetCollaboratorsResult]:
    """
    Use this data source to retrieve the collaborators for a given repository.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_github as github

    test = github.get_collaborators(owner="example_owner",
        repository="example_repository")
    ```


    :param str affiliation: Filter collaborators returned by their affiliation. Can be one of: `outside`, `direct`, `all`.  Defaults to `all`.
    :param str owner: The organization that owns the repository.
    :param str repository: The name of the repository.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = ['RepositoryTopicsArgs', 'RepositoryTopics']

@pulumi.input_type
class RepositoryTopicsArgs:
    def __init__(__self__, *,
                 repository: pulumi.Input[str],
                 topics: pulumi.Input[Sequence[pulumi.Input[str]]]):
        """
        The set of arguments for constructing a RepositoryTopics resource.
        :param pulumi.Input[str] repository: The repository name.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] topics: A list of topics to add to the repository.
        """
        pulumi.set(__self__, "repository", repository)
        pulumi.set(__self__, "topics", topics)

    @property
    @pulumi.getter
    def repository(self) -> pulumi.Input[str]:
        """
        The repository name.
        """
        return pulumi.get(self, "repository")

    @repository.setter
    def repository(self, value: pulumi.Input[str]):
        pulumi.set(self, "repository", value)

    @property
    @pulumi.getter
    def topics(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        A list of topics to add to the repository.
        """
        return pulumi.get(self, "topics")

    @topics.setter
    def topics(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "topics", value)


@pulumi.input_type
class _RepositoryTopicsState:
    def __init__(__self__, *,
                 repository: Optional[pulumi.Input[str]] = None,
                 topics: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        Input properties used for looking up and filtering RepositoryTopics resources.
        :param pulumi.Input[str] repository: The repository name.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] topics: A list of topics to add to the repository.
        """
        if repository is not None:
            pulumi.set(__self__, "repository", repository)
        if topics is not None:
            pulumi.set(__self__, "topics", topics)

    @property
    @pulumi.getter
    def repository(self) -> Optional[pulumi.Input[str]]:
        """
        The repository name.
        """
        return pulumi.get(self, "repository")

    @repository.setter
    def repository(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "repository", value)

    @property
    @pulumi.getter
    def topics(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of topics to add to the repository.
        """
        return pulumi.get(self, "topics")

    @topics.setter
    def topics(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "topics", value)


class RepositoryTopics(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 repository: Optional[pulumi.Input[str]] = None,
                 topics: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        test = github.get_repository(name="test")
        test_repository_topics = github.RepositoryTopics("test",
            repository=test_github_repository["name"],
            topics=[
                "topic-1",
                "topic-2",
            ])
        ```

        ## Import

        Repository topics can be imported using the `name` of the repository.

        ```sh
        $ pulumi import github:index/repositoryTopics:RepositoryTopics terraform terraform
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] repository: The repository name.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] topics: A list of topics to add to the repository.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RepositoryTopicsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_github as github

        test = github.get_repository(name="test")
        test_repository_topics = github.RepositoryTopics("test",
            repository=test_github_repository["name"],
            topics=[
                "topic-1",
                "topic-2",
            ])
        ```

        ## Import

        Repository topics can be imported using the `name` of the repository.

        ```sh
        $ pulumi import github:index/repositoryTopics:RepositoryTopics terraform terraform
        ```

        :param str resource_name: The name of the resource.
        :param RepositoryTopicsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RepositoryTopicsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 repository: Optional[pulumi.Input[str]] = None,
                 topics: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RepositoryTopicsArgs.__new__(RepositoryTopicsArgs)

            if repository is None and not opts.urn:
                raise TypeError("Missing required property 'repository'")
            __props__.__dict__["repository"] = repository
            if topics is None and not opts.urn:
                raise TypeError("Missing required property 'topics'")
            __props__.__dict__["topics"] = topics
        super(RepositoryTopics, __self__).__init__(
            'github:index/repositoryTopics:RepositoryTopics',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            repository: Optional[pulumi.Input[str]] = None,
            topics: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None) -> 'RepositoryTopics':
        """
        Get an existing RepositoryTopics resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] repository: The repository name.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] topics: A list of topics to add to the repository.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RepositoryTopicsState.__new__(_RepositoryTopicsState)

        __props__.__dict__["repository"] = repository
        __props__.__dict__["topics"] = topics
        return RepositoryTopics(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def repository(self) -> pulumi.Output[str]:
        """
        The repository name.
        """
        return pulumi.get(self, "repository")

    @property
    @pulumi.getter
    def topics(self) -> pulumi.Output[Sequence[str]]:
        """
        A list of topics to add to the repository.
        """
        return pulumi.get(self, "topics")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs

__all__ = [
    'GetRepositoryAutolinkReferencesResult',
    'AwaitableGetRepositoryAutolinkReferencesResult',
    'get_repository_autolink_references',
    'get_repository_autolink_references_output',
]

@pulumi.output_type
class GetRepositoryAutolinkReferencesResult:
    """
    A collection of values returned by getRepositoryAutolinkReferences.
    """
    def __init__(__self__, autolink_references=None, id=None, repository=None):
        if autolink_references and not isinstance(autolink_references, list):
            raise TypeError("Expected argument 'autolink_references' to be a list")
        pulumi.set(__self__, "autolink_references", autolink_references)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if repository and not isinstance(repository, str):
            raise TypeError("Expected argument 'repository' to be a str")
        pulumi.set(__self__, "repository", repository)

    @property
    @pulumi.getter(name="autolinkReferences")
    def autolink_references(self) -> Sequence['outputs.GetRepositoryAutolinkReferencesAutolinkReferenceResult']:
        """
        The list of this repository's autolink references. Each element of `autolink_references` has the following attributes:
        """
        return pulumi.get(self, "autolink_references")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def repository(self) -> str:
        return pulumi.get(self, "repository")


class AwaitableGetRepositoryAutolinkReferencesResult(GetRepositoryAutolinkReferencesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRepositoryAutolinkReferencesResult(
            autolink_references=self.autolink_references,
            id=self.id,
            repository=self.repository)


def get_repository_autolink_references(repository: Optional[str] = None,
                                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRepositoryAutolinkReferencesResult:
    """
    Use this data source to retrieve autolink references for a repository.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_github as github

    example = github.get_repository_autolink_references(repository="example-repository")
    ```


    :param str repository: Name of the repository to retrieve the autolink references from.
    """
    __args__ = dict()
    __args__['repository'] = repository
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('github:index/getRepositoryAutolinkReferences:getRepositoryAutolinkReferences', __args__, opts=opts, typ=GetRepositoryAutolinkReferencesResult).value

    return AwaitableGetRepositoryAutolinkReferencesResult(
        autolink_references=pulumi.get(__ret__, 'autolink_references'),
        id=pulumi.get(__ret__, 'id'),
        repository=pulumi.get(__ret__, 'repository'))


@_utilities.lift_output_func(get_repository_autolink_references)
def get_repository_autolink_references_output(repository: Optional[pulumi.Input[str]] = None,
                                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetRepositoryAutolinkReferencesResult]:
    """
    Use this data source to retrieve autolink references for a repository.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_github as github

    example = github.get_repository_autolink_references(repository="example-repository")
    ```


    :param str repository: Name of the repository to retrieve the autolink references from.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetActionsRepositoryOidcSubjectClaimCustomizationTemplateResult',
    'AwaitableGetActionsRepositoryOidcSubjectClaimCustomizationTemplateResult',
    'get_actions_repository_oidc_subject_claim_customization_template',
    'get_actions_repository_oidc_subject_claim_customization_template_output',
]

@pulumi.output_type
class GetActionsRepositoryOidcSubjectClaimCustomizationTemplateResult:
    """
    A collection of values returned by getActionsRepositoryOidcSubjectClaimCustomizationTemplate.
    """
    def __init__(__self__, id=None, include_claim_keys=None, name=None, use_default=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if include_claim_keys and not isinstance(include_claim_keys, list):
            raise TypeError("Expected argument 'include_claim_keys' to be a list")
        pulumi.set(__self__, "include_claim_keys", include_claim_keys)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if use_default and not isinstance(use_default, bool):
            raise TypeError("Expected argument 'use_default' to be a bool")
        pulumi.set(__self__, "use_default", use_default)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="includeClaimKeys")
    def include_claim_keys(self) -> Sequence[str]:
        """
        The list of OpenID Connect claim keys.
        """
        return pulumi.get(self, "include_claim_keys")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="useDefault")
    def use_default(self) -> bool:
        """
        Whether the repository uses the default template.
        """
        return pulumi.get(self, "use_default")


class AwaitableGetActionsRepositoryOidcSubjectClaimCustomizationTemplateResult(GetActionsRepositoryOidcSubjectClaimCustomizationTemplateResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetActionsRepositoryOidcSubjectClaimCustomizationTemplateResult(
            id=self.id,
            include_claim_keys=self.include_claim_keys,
            name=self.name,
            use_default=self.use_default)


def get_actions_repository_oidc_subject_claim_customization_template(name: Optional[str] = None,
                                                                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetActionsRepositoryOidcSubjectClaimCustomizationTemplateResult:
    """
    Use this data source to retrieve the OpenID Connect subject claim customization template for a repository

    ## Example Usage

    ```python
    import pulumi
    import pulumi_github as github

    example = github.get_actions_repository_oidc_subject_claim_customization_template(name="example_repository")
    ```


    :param str name: Name of the repository to get the OpenID Connect subject claim customization template for.
    """
    __args__ = dict()
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('github:index/getActionsRepositoryOidcSubjectClaimCustomizationTemplate:getActionsRepositoryOidcSubjectClaimCustomizationTemplate', __args__, opts=opts, typ=GetActionsRepositoryOidcSubjectClaimCustomizationTemplateResult).value

    return AwaitableGetActionsRepositoryOidcSubjectClaimCustomizationTemplateResult(
        id=pulumi.get(__ret__, 'id'),
        include_claim_keys=pulumi.get(__ret__, 'include_claim_keys'),
        name=pulumi.get(__ret__, 'name'),
        use_default=pulumi.get(__ret__, 'use_default'))


@_utilities.lift_output_func(get_actions_repository_oidc_subject_claim_customization_template)
def get_actions_repository_oidc_subject_claim_customization_template_output(name: Optional[pulumi.Input[str]] = None,
                                                                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetActionsRepositoryOidcSubjectClaimCustomizationTemplateResult]:
    """
    Use this data source to retrieve the OpenID Connect subject claim customization template for a repository

    ## Example Usage

    ```python
    import pulumi
    import pulumi_github as github

    example = github.get_actions_repository_oidc_subject_claim_customization_template(name="example_repository")
    ```


    :param str name: Name of the repository to get the OpenID Connect subject claim customization template for.
    """
    ...
